@@ -1,40 +1,29 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/Coordinate.h>
+#include "SFCGAL/Coordinate.h"
 
-#include <SFCGAL/Exception.h>
-#include <SFCGAL/Kernel.h>
-#include <SFCGAL/numeric.h>
+#include "SFCGAL/Exception.h"
+#include "SFCGAL/Kernel.h"
+#include "SFCGAL/numeric.h"
 
 namespace SFCGAL {
 
-///
-///
-///
 Coordinate::Coordinate() : _storage(Coordinate::Empty()) {}
 
-///
-///
-///
 Coordinate::Coordinate(const Kernel::FT &x, const Kernel::FT &y)
     : _storage(Kernel::Point_2(x, y))
 {
 }
 
-///
-///
-///
 Coordinate::Coordinate(const Kernel::FT &x, const Kernel::FT &y,
                        const Kernel::FT &z)
     : _storage(Kernel::Point_3(x, y, z))
 {
 }
 
-///
-///
-///
 Coordinate::Coordinate(const double &x, const double &y)
 {
   if (!std::isfinite(x) || !std::isfinite(y)) {
@@ -45,9 +34,6 @@ Coordinate::Coordinate(const double &x, const double &y)
   _storage = Kernel::Point_2(x, y);
 }
 
-///
-///
-///
 Coordinate::Coordinate(const double &x, const double &y, const double &z)
 {
   if (!std::isfinite(x) || !std::isfinite(y) || !std::isfinite(z)) {
@@ -58,30 +44,15 @@ Coordinate::Coordinate(const double &x, const double &y, const double &z)
   _storage = Kernel::Point_3(x, y, z);
 }
 
-///
-///
-///
 Coordinate::Coordinate(const Kernel::Point_2 &other) : _storage(other) {}
 
-///
-///
-///
 Coordinate::Coordinate(const Kernel::Point_3 &other) : _storage(other) {}
 
-///
-///
-///
 Coordinate::Coordinate(const Coordinate &other) = default;
 
-///
-///
-///
 auto
 Coordinate::operator=(const Coordinate &other) -> Coordinate & = default;
 
-///
-///
-///
 Coordinate::~Coordinate() = default;
 
 class CoordinateDimensionVisitor : public boost::static_visitor<int> {
@@ -103,9 +74,6 @@ public:
   }
 };
 
-///
-///
-///
 auto
 Coordinate::coordinateDimension() const -> int
 {
@@ -113,18 +81,12 @@ Coordinate::coordinateDimension() const -> int
   return boost::apply_visitor(visitor, _storage);
 }
 
-///
-///
-///
 auto
 Coordinate::isEmpty() const -> bool
 {
   return _storage.which() == 0;
 }
 
-///
-///
-///
 auto
 Coordinate::is3D() const -> bool
 {
@@ -152,9 +114,6 @@ public:
   }
 };
 
-///
-///
-///
 auto
 Coordinate::x() const -> Kernel::FT
 {
@@ -183,9 +142,6 @@ public:
   }
 };
 
-///
-///
-///
 auto
 Coordinate::y() const -> Kernel::FT
 {
@@ -214,9 +170,6 @@ public:
   }
 };
 
-///
-///
-///
 auto
 Coordinate::z() const -> Kernel::FT
 {
@@ -293,9 +246,6 @@ public:
   }
 };
 
-///
-///
-///
 auto
 Coordinate::toPoint_2() const -> Kernel::Point_2
 {
@@ -322,9 +272,6 @@ public:
   }
 };
 
-///
-///
-///
 auto
 Coordinate::toPoint_3() const -> Kernel::Point_3
 {
@@ -332,9 +279,6 @@ Coordinate::toPoint_3() const -> Kernel::Point_3
   return boost::apply_visitor(visitor, _storage);
 }
 
-///
-///
-///
 auto
 Coordinate::operator<(const Coordinate &other) const -> bool
 {
@@ -381,9 +325,6 @@ Coordinate::operator<(const Coordinate &other) const -> bool
   return false;
 }
 
-///
-///
-///
 auto
 Coordinate::operator==(const Coordinate &other) const -> bool
 {
@@ -397,9 +338,6 @@ Coordinate::operator==(const Coordinate &other) const -> bool
   return x() == other.x() && y() == other.y();
 }
 
-///
-///
-///
 auto
 Coordinate::operator!=(const Coordinate &other) const -> bool
 {
@@ -430,4 +368,25 @@ Coordinate::almostEqual(const Coordinate &other, const double tolerance) const
   return result;
 }
 
+auto
+Coordinate::dropZ() -> bool
+{
+  if (!is3D()) {
+    return false;
+  }
+
+  _storage = Kernel::Point_2(x(), y());
+  return true;
+}
+
+auto
+Coordinate::swapXY() -> void
+{
+  if (_storage.which() == 1) {
+    _storage = Kernel::Point_2(y(), x());
+  } else if (_storage.which() == 2) {
+    _storage = Kernel::Point_3(y(), x(), z());
+  }
+}
+
 } // namespace SFCGAL
