@@ -1,20 +1,21 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_COORDINATE_H_
-#define _SFCGAL_COORDINATE_H_
+#ifndef SFCGAL_COORDINATE_H_
+#define SFCGAL_COORDINATE_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
 #include <boost/array.hpp>
 #include <boost/assert.hpp>
 #include <boost/serialization/split_member.hpp>
 #include <boost/variant.hpp>
 
-#include <SFCGAL/numeric.h>
+#include "SFCGAL/numeric.h"
 
-#include <SFCGAL/Kernel.h>
+#include "SFCGAL/Kernel.h"
 
 namespace SFCGAL {
 
@@ -181,6 +182,19 @@ public:
   Kernel::Point_3
   toPoint_3() const;
 
+  /**
+   * @brief Drops the z coordinate
+   * @return TRUE if a Z value was present and has been removed
+   */
+  auto
+  dropZ() -> bool;
+
+  /**
+   * @brief Swaps the x and y coordinates
+   */
+  auto
+  swapXY() -> void;
+
   // class for Empty coordinate
   class Empty {};
 
