@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/Envelope.h"
@@ -12,9 +13,6 @@
 
 namespace SFCGAL {
 
-///
-///
-///
 Envelope::Envelope()
 {
   for (auto &_bound : _bounds) {
@@ -22,9 +20,6 @@ Envelope::Envelope()
   }
 }
 
-///
-///
-///
 Envelope::Envelope(const double &xmin, const double &xmax, const double &ymin,
                    const double &ymax)
 {
@@ -33,9 +28,6 @@ Envelope::Envelope(const double &xmin, const double &xmax, const double &ymin,
   _bounds[2] = detail::Interval();
 }
 
-///
-///
-///
 Envelope::Envelope(const double &xmin, const double &xmax, const double &ymin,
                    const double &ymax, const double &zmin, const double &zmax)
 {
@@ -44,23 +36,14 @@ Envelope::Envelope(const double &xmin, const double &xmax, const double &ymin,
   _bounds[2] = detail::Interval(zmin, zmax);
 }
 
-///
-///
-///
 Envelope::Envelope(const Coordinate &p) { expandToInclude(p); }
 
-///
-///
-///
 Envelope::Envelope(const Coordinate &p1, const Coordinate &p2)
 {
   expandToInclude(p1);
   expandToInclude(p2);
 }
 
-///
-///
-///
 Envelope::Envelope(const Envelope &other)
 {
   for (size_t i = 0; i < 3; i++) {
@@ -68,9 +51,6 @@ Envelope::Envelope(const Envelope &other)
   }
 }
 
-///
-///
-///
 auto
 Envelope::operator=(const Envelope &other) -> Envelope &
 {
@@ -81,31 +61,18 @@ Envelope::operator=(const Envelope &other) -> Envelope &
   return *this;
 }
 
-///
-///
-///
-
-///
-///
-///
 auto
 Envelope::isEmpty() const -> bool
 {
   return _bounds[0].isEmpty() || _bounds[1].isEmpty();
 }
 
-///
-///
-///
 auto
 Envelope::is3D() const -> bool
 {
   return !isEmpty() && !_bounds[2].isEmpty();
 }
 
-///
-///
-///
 void
 Envelope::expandToInclude(const Coordinate &coordinate)
 {
@@ -119,9 +86,6 @@ Envelope::expandToInclude(const Coordinate &coordinate)
   }
 }
 
-///
-///
-///
 auto
 Envelope::contains(const Envelope &a, const Envelope &b) -> bool
 {
@@ -135,9 +99,6 @@ Envelope::contains(const Envelope &a, const Envelope &b) -> bool
          b.yMax() <= a.yMax();
 }
 
-///
-///
-///
 auto
 Envelope::overlaps(const Envelope &a, const Envelope &b) -> bool
 {
@@ -152,9 +113,6 @@ Envelope::overlaps(const Envelope &a, const Envelope &b) -> bool
   return CGAL::do_overlap(abox, bbox);
 }
 
-///
-///
-///
 auto
 Envelope::toRing() const -> std::unique_ptr<LineString>
 {
@@ -173,18 +131,12 @@ Envelope::toRing() const -> std::unique_ptr<LineString>
   return ring;
 }
 
-///
-///
-///
 auto
 Envelope::toPolygon() const -> std::unique_ptr<Polygon>
 {
   return std::make_unique<Polygon>(toRing().release());
 }
 
-///
-///
-///
 auto
 Envelope::toShell() const -> std::unique_ptr<PolyhedralSurface>
 {
@@ -213,7 +165,7 @@ Envelope::toShell() const -> std::unique_ptr<PolyhedralSurface>
     ring.addPoint(b);
     ring.addPoint(ring.startPoint());
 
-    shell->addPolygon(Polygon(ring));
+    shell->addPatch(Polygon(ring));
   }
 
   // top : e,f,g,h
@@ -225,7 +177,7 @@ Envelope::toShell() const -> std::unique_ptr<PolyhedralSurface>
     ring.addPoint(h);
     ring.addPoint(ring.startPoint());
 
-    shell->addPolygon(Polygon(ring));
+    shell->addPatch(Polygon(ring));
   }
 
   // front : a,b,f,e
@@ -237,7 +189,7 @@ Envelope::toShell() const -> std::unique_ptr<PolyhedralSurface>
     ring.addPoint(e);
     ring.addPoint(ring.startPoint());
 
-    shell->addPolygon(Polygon(ring));
+    shell->addPatch(Polygon(ring));
   }
 
   // back : c,d,h,g
@@ -249,7 +201,7 @@ Envelope::toShell() const -> std::unique_ptr<PolyhedralSurface>
     ring.addPoint(g);
     ring.addPoint(ring.startPoint());
 
-    shell->addPolygon(Polygon(ring));
+    shell->addPatch(Polygon(ring));
   }
 
   // right : b,c,g,f
@@ -261,7 +213,7 @@ Envelope::toShell() const -> std::unique_ptr<PolyhedralSurface>
     ring.addPoint(f);
     ring.addPoint(ring.startPoint());
 
-    shell->addPolygon(Polygon(ring));
+    shell->addPatch(Polygon(ring));
   }
 
   // left : a,e,h,d
@@ -273,24 +225,18 @@ Envelope::toShell() const -> std::unique_ptr<PolyhedralSurface>
     ring.addPoint(d);
     ring.addPoint(ring.startPoint());
 
-    shell->addPolygon(Polygon(ring));
+    shell->addPatch(Polygon(ring));
   }
 
   return shell;
 }
 
-///
-///
-///
 auto
 Envelope::toSolid() const -> std::unique_ptr<Solid>
 {
   return std::make_unique<Solid>(toShell().release());
 }
 
-///
-///
-///
 auto
 Envelope::print(std::ostream &ostr) const -> std::ostream &
 {
