@@ -1,9 +1,10 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_GEOMETRYCOLLECTION_H_
-#define _SFCGAL_GEOMETRYCOLLECTION_H_
+#ifndef SFCGAL_GEOMETRYCOLLECTION_H_
+#define SFCGAL_GEOMETRYCOLLECTION_H_
 
 #include <boost/assert.hpp>
 #include <boost/ptr_container/ptr_vector.hpp>
@@ -11,13 +12,12 @@
 #include <boost/serialization/base_object.hpp>
 #include <vector>
 
-#include <SFCGAL/Geometry.h>
+#include "SFCGAL/Geometry.h"
 
 namespace SFCGAL {
 
 /**
  * A GeometryCollection in SFA.
- * @ingroup public_api
  */
 class SFCGAL_API GeometryCollection : public Geometry {
 public:
@@ -43,40 +43,56 @@ public:
   virtual ~GeometryCollection();
 
   //-- SFCGAL::Geometry
-  virtual GeometryCollection *
-  clone() const;
+  GeometryCollection *
+  clone() const override;
 
   //-- SFCGAL::Geometry
-  virtual std::string
-  geometryType() const;
+  std::string
+  geometryType() const override;
   //-- SFCGAL::Geometry
-  virtual GeometryType
-  geometryTypeId() const;
+  GeometryType
+  geometryTypeId() const override;
   //-- SFCGAL::Geometry
-  virtual int
-  dimension() const;
+  int
+  dimension() const override;
   //-- SFCGAL::Geometry
-  virtual int
-  coordinateDimension() const;
+  int
+  coordinateDimension() const override;
   //-- SFCGAL::Geometry
-  virtual bool
-  isEmpty() const;
+  bool
+  isEmpty() const override;
   //-- SFCGAL::Geometry
-  virtual bool
-  is3D() const;
+  bool
+  is3D() const override;
   //-- SFCGAL::Geometry
-  virtual bool
-  isMeasured() const;
+  bool
+  isMeasured() const override;
+
+  auto
+  dropZ() -> bool override;
+
+  auto
+  dropM() -> bool override;
+
+  auto
+  swapXY() -> void override;
 
   //-- SFCGAL::Geometry
-  virtual size_t
-  numGeometries() const;
+  size_t
+  numGeometries() const override;
   //-- SFCGAL::Geometry
-  virtual const Geometry &
-  geometryN(size_t const &n) const;
+  const Geometry &
+  geometryN(size_t const &n) const override;
   //-- SFCGAL::Geometry
-  virtual Geometry &
-  geometryN(size_t const &n);
+  Geometry &
+  geometryN(size_t const &n) override;
+
+  //-- SFCGAL::Geometry
+  virtual void
+  setGeometryN(const Geometry &geometry, size_t const &n) override;
+  //-- SFCGAL::Geometry
+  virtual void
+  setGeometryN(Geometry *geometry, size_t const &n) override;
 
   /**
    * [SFA/OGC]add a geometry to the collection (takes ownership)
@@ -116,11 +132,11 @@ public:
   //-- visitors
 
   //-- SFCGAL::Geometry
-  virtual void
-  accept(GeometryVisitor &visitor);
+  void
+  accept(GeometryVisitor &visitor) override;
   //-- SFCGAL::Geometry
-  virtual void
-  accept(ConstGeometryVisitor &visitor) const;
+  void
+  accept(ConstGeometryVisitor &visitor) const override;
 
   /**
    * Serializer
@@ -130,7 +146,7 @@ public:
   serialize(Archive &ar, const unsigned int /*version*/)
   {
     ar &boost::serialization::base_object<Geometry>(*this);
-    ar &_geometries;
+    ar & _geometries;
   }
 
 private:
