@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef SFCGAL_MULTILINESTRING_H_
@@ -17,7 +18,6 @@ namespace SFCGAL {
 
 /**
  * A MultiLineString in SFA.
- * @ingroup public_api
  */
 class SFCGAL_API MultiLineString : public GeometryCollection {
 public:
@@ -40,15 +40,15 @@ public:
   virtual ~MultiLineString();
 
   //-- SFCGAL::Geometry
-  virtual MultiLineString *
-  clone() const;
+  MultiLineString *
+  clone() const override;
 
   //-- SFCGAL::Geometry
-  virtual std::string
-  geometryType() const;
+  std::string
+  geometryType() const override;
   //-- SFCGAL::Geometry
-  virtual GeometryType
-  geometryTypeId() const;
+  GeometryType
+  geometryTypeId() const override;
 
   /**
    * returns the n-th Geometry as a Polygon
@@ -70,11 +70,11 @@ public:
   //-- visitors
 
   //-- SFCGAL::Geometry
-  virtual void
-  accept(GeometryVisitor &visitor);
+  void
+  accept(GeometryVisitor &visitor) override;
   //-- SFCGAL::Geometry
-  virtual void
-  accept(ConstGeometryVisitor &visitor) const;
+  void
+  accept(ConstGeometryVisitor &visitor) const override;
 
   /**
    * Serializer
@@ -88,8 +88,8 @@ public:
 
 protected:
   //-- SFCGAL::GeometryCollection
-  virtual bool
-  isAllowed(Geometry const &g);
+  bool
+  isAllowed(Geometry const &g) override;
 };
 
 } // namespace SFCGAL
