@@ -1,23 +1,23 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_MULTISOLID_H_
-#define _SFCGAL_MULTISOLID_H_
+#ifndef SFCGAL_MULTISOLID_H_
+#define SFCGAL_MULTISOLID_H_
 
 #include <boost/assert.hpp>
 #include <vector>
 
 #include <boost/serialization/base_object.hpp>
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/Solid.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/Solid.h"
 
 namespace SFCGAL {
 
 /**
  * A MultiSolid
- * @ingroup public_api
  */
 class SFCGAL_API MultiSolid : public GeometryCollection {
 public:
@@ -40,15 +40,15 @@ public:
   virtual ~MultiSolid();
 
   //-- SFCGAL::Geometry
-  virtual MultiSolid *
-  clone() const;
+  MultiSolid *
+  clone() const override;
 
   //-- SFCGAL::Geometry
-  virtual std::string
-  geometryType() const;
+  std::string
+  geometryType() const override;
   //-- SFCGAL::Geometry
-  virtual GeometryType
-  geometryTypeId() const;
+  GeometryType
+  geometryTypeId() const override;
 
   /**
    * returns the n-th Geometry as a Solid
@@ -70,11 +70,11 @@ public:
   //-- visitors
 
   //-- SFCGAL::Geometry
-  virtual void
-  accept(GeometryVisitor &visitor);
+  void
+  accept(GeometryVisitor &visitor) override;
   //-- SFCGAL::Geometry
-  virtual void
-  accept(ConstGeometryVisitor &visitor) const;
+  void
+  accept(ConstGeometryVisitor &visitor) const override;
 
   /**
    * Serializer
@@ -88,8 +88,8 @@ public:
 
 protected:
   //-- SFCGAL::GeometryCollection
-  virtual bool
-  isAllowed(Geometry const &g);
+  bool
+  isAllowed(Geometry const &g) override;
 };
 
 } // namespace SFCGAL
