@@ -1,22 +1,20 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Exception.h"
 #include "SFCGAL/GeometryVisitor.h"
 
+#include <CGAL/Cartesian_converter.h>
+
 using namespace SFCGAL::detail;
 
 namespace SFCGAL {
 
-///
-///
-///
 PolyhedralSurface::PolyhedralSurface() = default;
 
-///
-///
-///
 PolyhedralSurface::PolyhedralSurface(const std::vector<Polygon> &polygons)
 
 {
@@ -32,26 +30,20 @@ PolyhedralSurface::PolyhedralSurface(const std::unique_ptr<Geometry> &geometry)
   } else if (geometry->is<TriangulatedSurface>()) {
     const TriangulatedSurface &triangulatedSurface =
         geometry->as<TriangulatedSurface>();
-    for (size_t i = 0; i < triangulatedSurface.numTriangles(); ++i) {
-      this->addPolygon(triangulatedSurface.triangleN(i));
+    for (size_t i = 0; i < triangulatedSurface.numPatches(); ++i) {
+      this->addPatch(triangulatedSurface.patchN(i));
     }
   } else if (geometry->is<Polygon>()) {
-    this->addPolygon(geometry->as<Polygon>());
+    this->addPatch(geometry->as<Polygon>());
   } else {
     throw std::invalid_argument("Cannot convert geometry to PolyhedralSurface");
   }
 }
 
-///
-///
-///
 PolyhedralSurface::PolyhedralSurface(const PolyhedralSurface &other)
 
     = default;
 
-///
-///
-///
 PolyhedralSurface::PolyhedralSurface(const Mesh &sm)
 {
 
@@ -68,9 +60,24 @@ PolyhedralSurface::PolyhedralSurface(const Mesh &sm)
   }
 }
 
-///
-///
-///
+PolyhedralSurface::PolyhedralSurface(const InexactMesh &inexactMesh)
+{
+  using inexact_to_exact  = CGAL::Cartesian_converter<InexactKernel, Kernel>;
+  using vertex_descriptor = Mesh::Vertex_index;
+
+  inexact_to_exact toExact;
+  for (auto face : inexactMesh.faces()) {
+    auto *new_face = new LineString();
+    for (vertex_descriptor const vd :
+         vertices_around_face(inexactMesh.halfedge(face), inexactMesh)) {
+      new_face->addPoint(Point(toExact(inexactMesh.point(vd))));
+    }
+
+    new_face->addPoint(new_face->startPoint().clone());
+    _polygons.push_back(new Polygon(new_face));
+  }
+}
+
 auto
 PolyhedralSurface::operator=(PolyhedralSurface other) -> PolyhedralSurface &
 {
@@ -78,50 +85,32 @@ PolyhedralSurface::operator=(PolyhedralSurface other) -> PolyhedralSurface &
   return *this;
 }
 
-///
-///
-///
 PolyhedralSurface::~PolyhedralSurface() = default;
 
-///
-///
-///
 auto
 PolyhedralSurface::clone() const -> PolyhedralSurface *
 {
   return new PolyhedralSurface(*this);
 }
 
-///
-///
-///
 auto
 PolyhedralSurface::geometryType() const -> std::string
 {
   return "PolyhedralSurface";
 }
 
-///
-///
-///
 auto
 PolyhedralSurface::geometryTypeId() const -> GeometryType
 {
   return TYPE_POLYHEDRALSURFACE;
 }
 
-///
-///
-///
 auto
 PolyhedralSurface::dimension() const -> int
 {
   return 2;
 }
 
-///
-///
-///
 auto
 PolyhedralSurface::coordinateDimension() const -> int
 {
@@ -131,18 +120,12 @@ PolyhedralSurface::coordinateDimension() const -> int
   return _polygons.front().coordinateDimension();
 }
 
-///
-///
-///
 auto
 PolyhedralSurface::isEmpty() const -> bool
 {
   return _polygons.empty();
 }
 
-///
-///
-///
 auto
 PolyhedralSurface::is3D() const -> bool
 {
@@ -152,9 +135,6 @@ PolyhedralSurface::is3D() const -> bool
   return _polygons.front().is3D();
 }
 
-///
-///
-///
 auto
 PolyhedralSurface::isMeasured() const -> bool
 {
@@ -164,9 +144,42 @@ PolyhedralSurface::isMeasured() const -> bool
   return _polygons.front().isMeasured();
 }
 
-///
-///
-///
+auto
+PolyhedralSurface::dropZ() -> bool
+{
+  if (!is3D()) {
+    return false;
+  }
+
+  for (auto &_polygon : _polygons) {
+    _polygon.dropZ();
+  }
+
+  return true;
+}
+
+auto
+PolyhedralSurface::dropM() -> bool
+{
+  if (!isMeasured()) {
+    return false;
+  }
+
+  for (auto &_polygon : _polygons) {
+    _polygon.dropM();
+  }
+
+  return true;
+}
+
+auto
+PolyhedralSurface::swapXY() -> void
+{
+  for (auto &_polygon : _polygons) {
+    _polygon.swapXY();
+  }
+}
+
 auto
 PolyhedralSurface::toTriangulatedSurface() const -> TriangulatedSurface
 {
@@ -175,75 +188,93 @@ PolyhedralSurface::toTriangulatedSurface() const -> TriangulatedSurface
   return result;
 }
 
-///
-///
-///
 void
-PolyhedralSurface::addPolygon(const Polygon &polygon)
+PolyhedralSurface::addPatch(const Polygon &patch)
 {
-  addPolygon(polygon.clone());
+  addPatch(patch.clone());
 }
 
-///
-///
-///
 void
-PolyhedralSurface::addPolygon(Polygon *polygon)
+PolyhedralSurface::addPatch(Polygon *patch)
 {
-  BOOST_ASSERT(polygon != NULL);
-  _polygons.push_back(polygon);
+  BOOST_ASSERT(patch != NULL);
+  _polygons.push_back(patch);
 }
 
-///
-///
-///
 void
-PolyhedralSurface::addPolygons(const PolyhedralSurface &polyhedralSurface)
+PolyhedralSurface::addPatchs(const PolyhedralSurface &polyhedralSurface)
 {
-  for (size_t i = 0; i < polyhedralSurface.numPolygons(); i++) {
-    addPolygon(polyhedralSurface.polygonN(i));
+  for (size_t i = 0; i < polyhedralSurface.numPatches(); i++) {
+    addPatch(polyhedralSurface.patchN(i));
   }
 }
 
-///
-///
-///
-auto
-PolyhedralSurface::numGeometries() const -> size_t
+void
+PolyhedralSurface::addPolygon(const Polygon &polygon)
 {
-  return _polygons.size();
+  return addPatch(polygon);
 }
 
-///
-///
-///
-auto
-PolyhedralSurface::geometryN(size_t const &n) const -> const Polygon &
+void
+PolyhedralSurface::addPolygon(Polygon *polygon)
 {
-  return _polygons[n];
+  return addPatch(polygon);
 }
 
-///
-///
-///
-auto
-PolyhedralSurface::geometryN(size_t const &n) -> Polygon &
+void
+PolyhedralSurface::addPolygons(const PolyhedralSurface &polyhedralSurface)
 {
-  return _polygons[n];
+  return addPatchs(polyhedralSurface);
+}
+
+void
+PolyhedralSurface::setPatchN(Polygon *patch, size_t const &n)
+{
+  BOOST_ASSERT(patch != NULL);
+
+  if (n >= numPatches()) {
+    BOOST_THROW_EXCEPTION(
+        Exception((boost::format("Cannot set geometry at position %s. "
+                                 "PolyhedralSurface has only %d geometries.") %
+                   n % numPatches())
+                      .str()));
+  }
+
+  _polygons.replace(n, patch);
+}
+
+void
+PolyhedralSurface::setPatchN(const Polygon &patch, size_t const &n)
+{
+  setPatchN(patch.clone(), n);
+}
+
+void
+PolyhedralSurface::setPatchN(Geometry *geometry, size_t const &n)
+{
+  if (geometry->geometryTypeId() != TYPE_POLYGON) {
+    std::ostringstream oss;
+    oss << "try to set a '" << geometry->geometryType()
+        << "' in a PolyhedralSurface\n";
+    delete geometry; // we are responsible for the resource here
+    BOOST_THROW_EXCEPTION(InappropriateGeometryException(oss.str()));
+  }
+
+  setPatchN(dynamic_cast<Polygon *>(geometry), n);
+}
+
+void
+PolyhedralSurface::setPatchN(const Geometry &geometry, size_t const &n)
+{
+  setPatchN(geometry.clone(), n);
 }
 
-///
-///
-///
 void
 PolyhedralSurface::accept(GeometryVisitor &visitor)
 {
   return visitor.visit(*this);
 }
 
-///
-///
-///
 void
 PolyhedralSurface::accept(ConstGeometryVisitor &visitor) const
 {
