@@ -1,11 +1,12 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_SURFACE_H_
-#define _SFCGAL_SURFACE_H_
+#ifndef SFCGAL_SURFACE_H_
+#define SFCGAL_SURFACE_H_
 
-#include <SFCGAL/Geometry.h>
+#include "SFCGAL/Geometry.h"
 
 namespace SFCGAL {
 
@@ -20,8 +21,8 @@ public:
   virtual ~Surface();
 
   //-- SFCGAL::Geometry
-  virtual int
-  dimension() const;
+  int
+  dimension() const override;
 
   /**
    * [OGC/SFS]"The area of this Surface, as measured in the spatial reference
