@@ -1,20 +1,18 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include "SFCGAL/TriangulatedSurface.h"
+#include <boost/format.hpp>
+
+#include "SFCGAL/Exception.h"
 #include "SFCGAL/GeometryVisitor.h"
+#include "SFCGAL/TriangulatedSurface.h"
 
 namespace SFCGAL {
 
-///
-///
-///
 TriangulatedSurface::TriangulatedSurface() = default;
 
-///
-///
-///
 TriangulatedSurface::TriangulatedSurface(const std::vector<Triangle> &triangles)
 
 {
@@ -23,16 +21,10 @@ TriangulatedSurface::TriangulatedSurface(const std::vector<Triangle> &triangles)
   }
 }
 
-///
-///
-///
 TriangulatedSurface::TriangulatedSurface(const TriangulatedSurface &other)
 
     = default;
 
-///
-///
-///
 auto
 TriangulatedSurface::operator=(TriangulatedSurface other)
     -> TriangulatedSurface &
@@ -41,41 +33,26 @@ TriangulatedSurface::operator=(TriangulatedSurface other)
   return *this;
 }
 
-///
-///
-///
 TriangulatedSurface::~TriangulatedSurface() = default;
 
-///
-///
-///
 auto
 TriangulatedSurface::clone() const -> TriangulatedSurface *
 {
   return new TriangulatedSurface(*this);
 }
 
-///
-///
-///
 auto
 TriangulatedSurface::geometryType() const -> std::string
 {
   return "TriangulatedSurface";
 }
 
-///
-///
-///
 auto
 TriangulatedSurface::geometryTypeId() const -> GeometryType
 {
   return TYPE_TRIANGULATEDSURFACE;
 }
 
-///
-///
-///
 auto
 TriangulatedSurface::dimension() const -> int
 {
@@ -83,9 +60,6 @@ TriangulatedSurface::dimension() const -> int
   return 2;
 }
 
-///
-///
-///
 auto
 TriangulatedSurface::coordinateDimension() const -> int
 {
@@ -95,94 +69,156 @@ TriangulatedSurface::coordinateDimension() const -> int
   return _triangles[0].coordinateDimension();
 }
 
-///
-///
-///
 auto
 TriangulatedSurface::isEmpty() const -> bool
 {
   return _triangles.empty();
 }
 
-///
-///
-///
 auto
 TriangulatedSurface::is3D() const -> bool
 {
   return !_triangles.empty() && _triangles.front().is3D();
 }
 
-///
-///
-///
 auto
 TriangulatedSurface::isMeasured() const -> bool
 {
   return !_triangles.empty() && _triangles.front().isMeasured();
 }
 
-///
-///
-///
-void
-TriangulatedSurface::addTriangles(const TriangulatedSurface &other)
+auto
+TriangulatedSurface::dropZ() -> bool
 {
-  for (const auto &it : other) {
-    addTriangle(it);
+  if (!is3D()) {
+    return false;
+  }
+
+  for (auto &_triangle : _triangles) {
+    _triangle.dropZ();
+  }
+
+  return true;
+}
+
+auto
+TriangulatedSurface::dropM() -> bool
+{
+  if (!isMeasured()) {
+    return false;
+  }
+
+  for (auto &_triangle : _triangles) {
+    _triangle.dropM();
+  }
+
+  return true;
+}
+
+auto
+TriangulatedSurface::swapXY() -> void
+{
+  for (auto &_triangle : _triangles) {
+    _triangle.swapXY();
   }
 }
 
-///
-///
-///
-auto
-TriangulatedSurface::numGeometries() const -> size_t
+void
+TriangulatedSurface::addPatchs(const TriangulatedSurface &other)
 {
-  return _triangles.size();
+  for (const auto &it : other) {
+    addPatch(it);
+  }
 }
 
-///
-///
-///
-auto
-TriangulatedSurface::geometryN(size_t const &n) const -> const Triangle &
+void
+TriangulatedSurface::addTriangles(const TriangulatedSurface &other)
 {
-  BOOST_ASSERT(n < numGeometries());
+  return addPatchs(other);
+}
+
+auto
+TriangulatedSurface::patchN(size_t const &n) const -> const Triangle &
+{
+  if (n >= numPatches()) {
+    BOOST_THROW_EXCEPTION(Exception(
+        (boost::format("Cannot access geometry at position %s. "
+                       "TriangulatedSurface has only %d geometries.") %
+         n % numGeometries())
+            .str()));
+  }
+
   return _triangles[n];
 }
 
-///
-///
-///
 auto
-TriangulatedSurface::geometryN(size_t const &n) -> Triangle &
+TriangulatedSurface::patchN(size_t const &n) -> Triangle &
 {
-  BOOST_ASSERT(n < numGeometries());
+  if (n >= numPatches()) {
+    BOOST_THROW_EXCEPTION(Exception(
+        (boost::format("Cannot access geometry at position %s. "
+                       "TriangulatedSurface has only %d geometries.") %
+         n % numPatches())
+            .str()));
+  }
+
   return _triangles[n];
 }
 
-///
-///
-///
+void
+TriangulatedSurface::setPatchN(Triangle *triangle, size_t const &n)
+{
+  BOOST_ASSERT(triangle != NULL);
+
+  if (n >= numPatches()) {
+    BOOST_THROW_EXCEPTION(Exception(
+        (boost::format("Cannot set geometry at position %s. "
+                       "TriangulatedSurface has only %d geometries.") %
+         n % numPatches())
+            .str()));
+  }
+
+  _triangles.replace(n, triangle);
+}
+
+void
+TriangulatedSurface::setPatchN(const Triangle &triangle, size_t const &n)
+{
+  setPatchN(triangle.clone(), n);
+}
+
+void
+TriangulatedSurface::setPatchN(Geometry *geometry, size_t const &n)
+{
+  if (geometry->geometryTypeId() != TYPE_TRIANGLE) {
+    std::ostringstream oss;
+    oss << "try to set a '" << geometry->geometryType()
+        << "' in a TriangulatedSurface\n";
+    delete geometry; // we are responsible for the resource here
+    BOOST_THROW_EXCEPTION(InappropriateGeometryException(oss.str()));
+  }
+
+  setPatchN(dynamic_cast<Triangle *>(geometry), n);
+}
+
+void
+TriangulatedSurface::setPatchN(const Geometry &geometry, size_t const &n)
+{
+  setPatchN(geometry.clone(), n);
+}
+
 void
 TriangulatedSurface::reserve(const size_t &n)
 {
   _triangles.reserve(n);
 }
 
-///
-///
-///
 void
 TriangulatedSurface::accept(GeometryVisitor &visitor)
 {
   return visitor.visit(*this);
 }
 
-///
-///
-///
 void
 TriangulatedSurface::accept(ConstGeometryVisitor &visitor) const
 {
@@ -206,19 +242,20 @@ public:
   void
   operator()(HDS &hds) override
   {
+    const size_t nrPatchs = surf.numPatches();
     // Postcondition: `hds' is a valid polyhedral surface.
     CGAL::Polyhedron_incremental_builder_3<HDS> B(hds, true);
-    B.begin_surface(/* vertices */ surf.numGeometries() * 3,
-                    /* facets */ surf.numGeometries(),
-                    /* halfedges */ surf.numGeometries() * 3);
+    B.begin_surface(/* vertices */ nrPatchs * 3,
+                    /* facets */ nrPatchs,
+                    /* halfedges */ nrPatchs * 3);
 
     size_t vertex_idx = 0;
 
     // first pass: insert vertices, only if they are not shared between faces
     // thanks to a binary tree (PointMap)
-    for (size_t i = 0; i < surf.numGeometries(); i++) {
+    for (size_t i = 0; i < nrPatchs; i++) {
       for (size_t j = 0; j < 3; j++) {
-        Point const p = surf.geometryN(i).vertex(j).toPoint_3();
+        Point const p = surf.patchN(i).vertex(j).toPoint_3();
 
         if (points.find(p) == points.end()) {
           B.add_vertex(p);
@@ -234,9 +271,9 @@ public:
     // "The convention is that the halfedges are oriented counterclockwise
     // around facets as seen from the outside of the polyhedron"
 
-    for (size_t i = 0; i < surf.numGeometries(); i++) {
+    for (size_t i = 0; i < nrPatchs; i++) {
       B.begin_facet();
-      CGAL::Triangle_3<K> const tri(surf.geometryN(i).toTriangle_3());
+      CGAL::Triangle_3<K> const tri(surf.patchN(i).toTriangle_3());
       CGAL::Point_3<K> const    pa(tri[0]);
       CGAL::Point_3<K> const    pb(tri[1]);
       CGAL::Point_3<K> const    pc(tri[2]);
