@@ -1,14 +1,15 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_BOUNDARYVISITOR_H_
-#define _SFCGAL_ALGORITHM_BOUNDARYVISITOR_H_
+#ifndef SFCGAL_ALGORITHM_BOUNDARYVISITOR_H_
+#define SFCGAL_ALGORITHM_BOUNDARYVISITOR_H_
 
-#include <SFCGAL/GeometryVisitor.h>
+#include "SFCGAL/GeometryVisitor.h"
 
-#include <SFCGAL/detail/graph/GeometryGraph.h>
-#include <SFCGAL/detail/graph/GeometryGraphBuilder.h>
+#include "SFCGAL/detail/graph/GeometryGraph.h"
+#include "SFCGAL/detail/graph/GeometryGraphBuilder.h"
 
 namespace SFCGAL {
 namespace algorithm {
@@ -42,30 +43,30 @@ namespace algorithm {
  */
 class SFCGAL_API BoundaryVisitor : public ConstGeometryVisitor {
 public:
-  virtual void
-  visit(const Point &g);
-  virtual void
-  visit(const LineString &g);
-  virtual void
-  visit(const Polygon &g);
-  virtual void
-  visit(const Triangle &g);
-  virtual void
-  visit(const Solid &g);
-  virtual void
-  visit(const MultiPoint &g);
-  virtual void
-  visit(const MultiLineString &g);
-  virtual void
-  visit(const MultiPolygon &g);
-  virtual void
-  visit(const MultiSolid &g);
-  virtual void
-  visit(const GeometryCollection &g);
-  virtual void
-  visit(const PolyhedralSurface &g);
-  virtual void
-  visit(const TriangulatedSurface &g);
+  void
+  visit(const Point &g) override;
+  void
+  visit(const LineString &g) override;
+  void
+  visit(const Polygon &g) override;
+  void
+  visit(const Triangle &g) override;
+  void
+  visit(const Solid &g) override;
+  void
+  visit(const MultiPoint &g) override;
+  void
+  visit(const MultiLineString &g) override;
+  void
+  visit(const MultiPolygon &g) override;
+  void
+  visit(const MultiSolid &g) override;
+  void
+  visit(const GeometryCollection &g) override;
+  void
+  visit(const PolyhedralSurface &g) override;
+  void
+  visit(const TriangulatedSurface &g) override;
 
   /**
    * get the boundary
