@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/algorithm/area.h"
@@ -28,18 +29,6 @@
 #include <boost/format.hpp>
 
 namespace SFCGAL::algorithm {
-
-using Point_2    = CGAL::Point_2<SFCGAL::Kernel>;
-using Triangle_2 = CGAL::Triangle_2<SFCGAL::Kernel>;
-using Polygon_2  = CGAL::Polygon_2<SFCGAL::Kernel>;
-
-using Point_3    = CGAL::Point_3<SFCGAL::Kernel>;
-using Triangle_3 = CGAL::Triangle_3<SFCGAL::Kernel>;
-using Plane_3    = CGAL::Plane_3<SFCGAL::Kernel>;
-
-///
-///
-///
 auto
 area(const Geometry &g, NoValidityCheck /*unused*/) -> double
 {
@@ -85,9 +74,6 @@ area(const Geometry &g) -> double
   return area(g, NoValidityCheck());
 }
 
-///
-///
-///
 auto
 signedArea(const Triangle &g) -> Kernel::FT
 {
@@ -95,27 +81,18 @@ signedArea(const Triangle &g) -> Kernel::FT
   return triangle.area();
 }
 
-///
-///
-///
 auto
 signedArea(const LineString &g) -> Kernel::FT
 {
   return g.toPolygon_2(false).area();
 }
 
-///
-///
-///
 auto
 area(const Triangle &g) -> double
 {
   return CGAL::to_double(CGAL::abs(signedArea(g)));
 }
 
-///
-///
-///
 auto
 area(const Polygon &g) -> double
 {
@@ -136,9 +113,6 @@ area(const Polygon &g) -> double
   return CGAL::to_double(result);
 }
 
-///
-///
-///
 auto
 area(const GeometryCollection &g) -> double
 {
@@ -151,43 +125,34 @@ area(const GeometryCollection &g) -> double
   return result;
 }
 
-///
-///
-///
 auto
 area(const TriangulatedSurface &g) -> double
 {
   double result = 0.0;
 
-  for (size_t i = 0; i < g.numTriangles(); i++) {
-    result += area(g.triangleN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    result += area(g.patchN(i));
   }
 
   return result;
 }
 
-///
-///
-///
 auto
 area(const PolyhedralSurface &g) -> double
 {
   double result = 0.0;
 
-  for (size_t i = 0; i < g.numPolygons(); i++) {
-    result += area(g.polygonN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    result += area(g.patchN(i));
   }
 
   return result;
 }
 
-///----------------------------------------------------------------------------------
-/// -- area3D
-///----------------------------------------------------------------------------------
+// ----------------------------------------------------------------------------------
+//  -- area3D
+// ----------------------------------------------------------------------------------
 
-///
-///
-///
 auto
 area3D(const Geometry &g, NoValidityCheck /*unused*/) -> double
 {
@@ -228,9 +193,7 @@ area3D(const Geometry &g) -> double
   SFCGAL_ASSERT_GEOMETRY_VALIDITY_3D(g);
   return area3D(g, NoValidityCheck());
 }
-///
-///
-///
+
 auto
 area3D(const Polygon &g) -> double
 {
@@ -285,9 +248,6 @@ area3D(const Polygon &g) -> double
   return result;
 }
 
-///
-///
-///
 auto
 area3D(const Triangle &g) -> double
 {
@@ -297,9 +257,6 @@ area3D(const Triangle &g) -> double
   return sqrt(CGAL::to_double(triangle.squared_area()));
 }
 
-///
-///
-///
 auto
 area3D(const GeometryCollection &g) -> double
 {
@@ -312,31 +269,25 @@ area3D(const GeometryCollection &g) -> double
   return result;
 }
 
-///
-///
-///
 auto
 area3D(const PolyhedralSurface &g) -> double
 {
   double area = 0.0;
 
-  for (size_t i = 0; i < g.numPolygons(); i++) {
-    area += area3D(g.polygonN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    area += area3D(g.patchN(i));
   }
 
   return area;
 }
 
-///
-///
-///
 auto
 area3D(const TriangulatedSurface &g) -> double
 {
   double result = 0.0;
 
-  for (size_t i = 0; i < g.numGeometries(); i++) {
-    result += area3D(g.geometryN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    result += area3D(g.patchN(i));
   }
 
   return result;
