@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/algorithm/convexHull.h"
@@ -25,16 +26,6 @@
 
 namespace SFCGAL::algorithm {
 
-using Point_3      = CGAL::Point_3<Kernel>;
-using Segment_3    = CGAL::Segment_3<Kernel>;
-using Triangle_3   = CGAL::Triangle_3<Kernel>;
-using Polyhedron_3 = CGAL::Polyhedron_3<Kernel>;
-
-using Point_2 = CGAL::Point_2<Kernel>;
-
-///
-///
-///
 auto
 convexHull(const Geometry &g) -> std::unique_ptr<Geometry>
 {
@@ -96,9 +87,6 @@ convexHull(const Geometry &g) -> std::unique_ptr<Geometry>
       Exception("unexpected CGAL output type in CGAL::convex_hull_2"));
 }
 
-///
-///
-///
 auto
 convexHull3D(const Geometry &g) -> std::unique_ptr<Geometry>
 {
@@ -157,7 +145,7 @@ convexHull3D(const Geometry &g) -> std::unique_ptr<Geometry>
 
       ring.push_back(ring.front());
 
-      result->addPolygon(Polygon(ring));
+      result->addPatch(Polygon(ring));
     }
 
     return std::unique_ptr<Geometry>(result.release());
