@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/algorithm/difference.h"
@@ -23,11 +24,17 @@ using namespace SFCGAL::detail;
 
 namespace SFCGAL::algorithm {
 
+// ----------------------------------------------------------------------------------
+// -- private interface
+// ----------------------------------------------------------------------------------
+/// @{
+/// @privatesection
+
 template <int Dim>
 struct CollisionMapper {
   using PrimitiveHandleSet = std::vector<PrimitiveHandle<Dim> *>;
   using Map = std::map<PrimitiveHandle<Dim> *, PrimitiveHandleSet>;
-  CollisionMapper(Map &map) : _map(map){};
+  CollisionMapper(Map &map) : _map(map) {};
   void
   operator()(const typename PrimitiveBox<Dim>::Type &a,
              const typename PrimitiveBox<Dim>::Type &b)
@@ -54,7 +61,7 @@ difference(const Point_2 &primitive, const PrimitiveHandle<2> &pb,
     break;
 
   case PrimitiveSurface:
-    difference(primitive, *pb.as<PolygonWH_2>(), out);
+    difference(primitive, *pb.as<Polygon_with_holes_2>(), out);
     break;
   }
 
@@ -76,7 +83,7 @@ difference(const Segment_2 &primitive, const PrimitiveHandle<2> &pb,
     break;
 
   case PrimitiveSurface:
-    difference(primitive, *pb.as<PolygonWH_2>(), out);
+    difference(primitive, *pb.as<Polygon_with_holes_2>(), out);
     break;
   }
 
@@ -85,7 +92,7 @@ difference(const Segment_2 &primitive, const PrimitiveHandle<2> &pb,
 
 template <typename OutputIteratorType>
 auto
-difference(const PolygonWH_2 &primitive, const PrimitiveHandle<2> &pb,
+difference(const Polygon_with_holes_2 &primitive, const PrimitiveHandle<2> &pb,
            OutputIteratorType out) -> OutputIteratorType
 {
   switch (pb.handle.which()) {
@@ -98,7 +105,7 @@ difference(const PolygonWH_2 &primitive, const PrimitiveHandle<2> &pb,
     break;
 
   case PrimitiveSurface:
-    difference(primitive, *pb.as<PolygonWH_2>(), out);
+    difference(primitive, *pb.as<Polygon_with_holes_2>(), out);
     break;
   }
 
@@ -230,8 +237,7 @@ difference(const Primitive &primitive, PrimitiveHandleConstIterator begin,
   return primitives;
 }
 
-// just performs the type switch for the primitive to substract from
-//
+/// just performs the type switch for the primitive to substract from
 void
 appendDifference(const PrimitiveHandle<2>                              &pa,
                  CollisionMapper<2>::PrimitiveHandleSet::const_iterator begin,
@@ -252,8 +258,8 @@ appendDifference(const PrimitiveHandle<2>                              &pa,
   }
 
   case PrimitiveSurface: {
-    std::vector<PolygonWH_2> res =
-        difference(*pa.as<PolygonWH_2>(), begin, end);
+    std::vector<Polygon_with_holes_2> res =
+        difference(*pa.as<Polygon_with_holes_2>(), begin, end);
     output.addSurfaces(res.begin(), res.end());
     return;
   }
@@ -303,8 +309,8 @@ post_difference(const GeometrySet<2> &input, GeometrySet<2> &output)
   //
   // reverse orientation of polygons if needed
   for (const auto &it : input.surfaces()) {
-    const PolygonWH_2 &p     = it.primitive();
-    Polygon_2          outer = p.outer_boundary();
+    const Polygon_with_holes_2 &p     = it.primitive();
+    Polygon_2                   outer = p.outer_boundary();
 
     if (outer.orientation() == CGAL::CLOCKWISE) {
       outer.reverse_orientation();
@@ -321,7 +327,7 @@ post_difference(const GeometrySet<2> &input, GeometrySet<2> &output)
     }
 
     output.surfaces().emplace_back(
-        PolygonWH_2(outer, rings.begin(), rings.end()));
+        Polygon_with_holes_2(outer, rings.begin(), rings.end()));
   }
 
   output.points()   = input.points();
@@ -394,6 +400,13 @@ template void
 difference<3>(const GeometrySet<3> &a, const GeometrySet<3> &b,
               GeometrySet<3> &);
 
+/// @} end of private section
+
+// ----------------------------------------------------------------------------------
+// -- public interface
+// ----------------------------------------------------------------------------------
+/// @publicsection
+
 auto
 difference(const Geometry &ga, const Geometry &gb, NoValidityCheck /*unused*/)
     -> std::unique_ptr<Geometry>
