@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/algorithm/distance.h"
@@ -24,18 +25,8 @@
 #include "SFCGAL/detail/GetPointsVisitor.h"
 #include "SFCGAL/detail/transform/AffineTransform3.h"
 
-using Point_2   = SFCGAL::Kernel::Point_2;
-using Vector_2  = SFCGAL::Kernel::Vector_2;
-using Segment_2 = SFCGAL::Kernel::Segment_2;
-
-using Polygon_2            = CGAL::Polygon_2<SFCGAL::Kernel>;
-using Polygon_with_holes_2 = CGAL::Polygon_with_holes_2<SFCGAL::Kernel>;
-
 namespace SFCGAL::algorithm {
 
-///
-///
-///
 auto
 distance(const Geometry &gA, const Geometry &gB, NoValidityCheck /*unused*/)
     -> double
@@ -81,9 +72,6 @@ distance(const Geometry &gA, const Geometry &gB) -> double
   return distance(gA, gB, NoValidityCheck());
 }
 
-///
-///
-///
 auto
 distancePointGeometry(const Point &gA, const Geometry &gB) -> double
 {
@@ -121,9 +109,6 @@ distancePointGeometry(const Point &gA, const Geometry &gB) -> double
   return 0;
 }
 
-///
-///
-///
 auto
 distancePointPoint(const Point &gA, const Point &gB) -> double
 {
@@ -135,9 +120,6 @@ distancePointPoint(const Point &gA, const Point &gB) -> double
       CGAL::to_double(CGAL::squared_distance(gA.toPoint_2(), gB.toPoint_2())));
 }
 
-///
-///
-///
 auto
 distancePointLineString(const Point &gA, const LineString &gB) -> double
 {
@@ -160,9 +142,6 @@ distancePointLineString(const Point &gA, const LineString &gB) -> double
   return dMin;
 }
 
-///
-///
-///
 auto
 distancePointPolygon(const Point &gA, const Polygon &gB) -> double
 {
@@ -188,18 +167,12 @@ distancePointPolygon(const Point &gA, const Polygon &gB) -> double
   return dMin;
 }
 
-///
-///
-///
 auto
 distancePointTriangle(const Point &gA, const Triangle &gB) -> double
 {
   return distancePointPolygon(gA, gB.toPolygon());
 }
 
-///
-///
-///
 auto
 distanceLineStringGeometry(const LineString &gA, const Geometry &gB) -> double
 {
@@ -241,9 +214,6 @@ distanceLineStringGeometry(const LineString &gA, const Geometry &gB) -> double
   return 0;
 }
 
-///
-///
-///
 auto
 distanceLineStringLineString(const LineString &gA, const LineString &gB)
     -> double
@@ -268,9 +238,6 @@ distanceLineStringLineString(const LineString &gA, const LineString &gB)
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceLineStringPolygon(const LineString &gA, const Polygon &gB) -> double
 {
@@ -295,18 +262,12 @@ distanceLineStringPolygon(const LineString &gA, const Polygon &gB) -> double
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceLineStringTriangle(const LineString &gA, const Triangle &gB) -> double
 {
   return distanceLineStringPolygon(gA, gB.toPolygon());
 }
 
-///
-///
-///
 auto
 distancePolygonGeometry(const Polygon &gA, const Geometry &gB) -> double
 {
@@ -348,9 +309,6 @@ distancePolygonGeometry(const Polygon &gA, const Geometry &gB) -> double
   return 0;
 }
 
-///
-///
-///
 auto
 distancePolygonPolygon(const Polygon &gA, const Polygon &gB) -> double
 {
@@ -377,18 +335,12 @@ distancePolygonPolygon(const Polygon &gA, const Polygon &gB) -> double
   return dMin;
 }
 
-///
-///
-///
 auto
 distancePolygonTriangle(const Polygon &gA, const Triangle &gB) -> double
 {
   return distancePolygonPolygon(gA, gB.toPolygon());
 }
 
-///
-///
-///
 auto
 distanceTriangleGeometry(const Triangle &gA, const Geometry &gB) -> double
 {
@@ -440,8 +392,6 @@ boundingCircle(const Geometry &geom) -> const Circle
     return Circle();
   }
 
-  using Vector_2 = CGAL::Vector_2<Kernel>;
-
   const auto end = v.points.end();
 
   // centroid
@@ -473,9 +423,6 @@ boundingCircle(const Geometry &geom) -> const Circle
   return Circle(std::sqrt(CGAL::to_double(maxDistanceSq)), c);
 }
 
-///
-///
-///
 auto
 distanceGeometryCollectionToGeometry(const Geometry &gA, const Geometry &gB)
     -> double
@@ -556,11 +503,6 @@ distanceGeometryCollectionToGeometry(const Geometry &gA, const Geometry &gB)
   return dMin;
 }
 
-//--- private
-
-///
-///
-///
 auto
 distancePointSegment(const Point &p, const Point &a, const Point &b) -> double
 {
@@ -573,9 +515,6 @@ distancePointSegment(const Point &p, const Point &a, const Point &b) -> double
       p.toPoint_2(), Segment_2(a.toPoint_2(), b.toPoint_2()))));
 }
 
-///
-///
-///
 auto
 distanceSegmentSegment(const Point &a, const Point &b, const Point &c,
                        const Point &d) -> double
