@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/algorithm/distance3d.h"
@@ -24,20 +25,16 @@
 #include "SFCGAL/detail/transform/AffineTransform3.h"
 #include "SFCGAL/triangulate/triangulatePolygon.h"
 
-using Kernel             = CGAL::Exact_predicates_exact_constructions_kernel;
+// ----------------------------------------------------------------------------------
+// -- private interface
+// ----------------------------------------------------------------------------------
+/// @{
+/// @privatesection
+namespace SFCGAL {
 using squared_distance_t = Kernel::FT;
 
-using Point_3    = Kernel::Point_3;
-using Vector_3   = Kernel::Vector_3;
-using Segment_3  = Kernel::Segment_3;
-using Triangle_3 = Kernel::Triangle_3;
-using Plane_3    = Kernel::Plane_3;
+namespace algorithm {
 
-namespace SFCGAL::algorithm {
-
-///
-///
-///
 auto
 distance3D(const Geometry &gA, const Geometry &gB, NoValidityCheck /*unused*/)
     -> double
@@ -62,6 +59,13 @@ distance3D(const Geometry &gA, const Geometry &gB, NoValidityCheck /*unused*/)
     // gA.geometryTypeId() );
     return distanceTriangleGeometry3D(gA.as<Triangle>(), gB);
 
+  case TYPE_POLYHEDRALSURFACE:
+    return distancePolyhedralSurfaceGeometry3D(gA.as<PolyhedralSurface>(), gB);
+
+  case TYPE_TRIANGULATEDSURFACE:
+    return distanceTriangulatedSurfaceGeometry3D(gA.as<TriangulatedSurface>(),
+                                                 gB);
+
   case TYPE_SOLID:
     return distanceSolidGeometry3D(gA.as<Solid>(), gB);
 
@@ -71,8 +75,6 @@ distance3D(const Geometry &gA, const Geometry &gB, NoValidityCheck /*unused*/)
   case TYPE_MULTIPOLYGON:
   case TYPE_MULTISOLID:
   case TYPE_GEOMETRYCOLLECTION:
-  case TYPE_TRIANGULATEDSURFACE:
-  case TYPE_POLYHEDRALSURFACE:
     return distanceGeometryCollectionToGeometry3D(gB, gA);
   }
 
@@ -90,9 +92,6 @@ distance3D(const Geometry &gA, const Geometry &gB) -> double
 
   return distance3D(gA, gB, NoValidityCheck());
 }
-///
-///
-///
 auto
 distancePointGeometry3D(const Point &gA, const Geometry &gB) -> double
 {
@@ -112,6 +111,12 @@ distancePointGeometry3D(const Point &gA, const Geometry &gB) -> double
   case TYPE_POLYGON:
     return distancePointPolygon3D(gA, gB.as<Polygon>());
 
+  case TYPE_POLYHEDRALSURFACE:
+    return distancePointPolyhedralSurface3D(gA, gB.as<PolyhedralSurface>());
+
+  case TYPE_TRIANGULATEDSURFACE:
+    return distancePointTriangulatedSurface3D(gA, gB.as<TriangulatedSurface>());
+
   case TYPE_SOLID:
     return distancePointSolid3D(gA, gB.as<Solid>());
 
@@ -120,8 +125,6 @@ distancePointGeometry3D(const Point &gA, const Geometry &gB) -> double
   case TYPE_MULTIPOLYGON:
   case TYPE_MULTISOLID:
   case TYPE_GEOMETRYCOLLECTION:
-  case TYPE_TRIANGULATEDSURFACE:
-  case TYPE_POLYHEDRALSURFACE:
     return distanceGeometryCollectionToGeometry3D(gB, gA);
   }
 
@@ -131,9 +134,6 @@ distancePointGeometry3D(const Point &gA, const Geometry &gB) -> double
                     .str()));
 }
 
-///
-///
-///
 auto
 distancePointPoint3D(const Point &gA, const Point &gB) -> double
 {
@@ -145,9 +145,6 @@ distancePointPoint3D(const Point &gA, const Point &gB) -> double
       CGAL::to_double(CGAL::squared_distance(gA.toPoint_3(), gB.toPoint_3())));
 }
 
-///
-///
-///
 auto
 distancePointLineString3D(const Point &gA, const LineString &gB) -> double
 {
@@ -165,9 +162,6 @@ distancePointLineString3D(const Point &gA, const LineString &gB) -> double
   return dMin;
 }
 
-///
-///
-///
 auto
 distancePointTriangle3D(const Point &gA, const Triangle &gB) -> double
 {
@@ -178,9 +172,6 @@ distancePointTriangle3D(const Point &gA, const Triangle &gB) -> double
   return distancePointTriangle3D(gA, gB.vertex(0), gB.vertex(1), gB.vertex(2));
 }
 
-///
-///
-///
 auto
 distancePointPolygon3D(const Point &gA, const Polygon &gB) -> double
 {
@@ -190,12 +181,55 @@ distancePointPolygon3D(const Point &gA, const Polygon &gB) -> double
 
   TriangulatedSurface triangulateSurfaceB;
   triangulate::triangulatePolygon3D(gB, triangulateSurfaceB);
-  return distanceGeometryCollectionToGeometry3D(triangulateSurfaceB, gA);
+  return distancePointTriangulatedSurface3D(gA, triangulateSurfaceB);
+}
+
+auto
+distancePointPolyhedralSurface3D(const Point             &pointA,
+                                 const PolyhedralSurface &polySurfaceB)
+    -> double
+{
+  if (pointA.isEmpty() || polySurfaceB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects3D(pointA, polySurfaceB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < polySurfaceB.numPatches(); i++) {
+    dMin = std::min(dMin,
+                    distancePolygonGeometry3D(polySurfaceB.patchN(i), pointA));
+  }
+
+  return dMin;
+}
+
+auto
+distancePointTriangulatedSurface3D(
+    const Point &pointA, const TriangulatedSurface &triangulatedSurfaceB)
+    -> double
+{
+  if (pointA.isEmpty() || triangulatedSurfaceB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects3D(pointA, triangulatedSurfaceB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < triangulatedSurfaceB.numPatches(); i++) {
+    dMin = std::min(dMin, distancePolygonGeometry3D(
+                              triangulatedSurfaceB.patchN(i), pointA));
+  }
+
+  return dMin;
 }
 
-///
-///
-///
 auto
 distancePointSolid3D(const Point &gA, const Solid &gB) -> double
 {
@@ -210,16 +244,12 @@ distancePointSolid3D(const Point &gA, const Solid &gB) -> double
   double dMin = std::numeric_limits<double>::infinity();
 
   for (size_t i = 0; i < gB.numShells(); i++) {
-    dMin = std::min(dMin,
-                    distanceGeometryCollectionToGeometry3D(gB.shellN(i), gA));
+    dMin = std::min(dMin, distancePointPolyhedralSurface3D(gA, gB.shellN(i)));
   }
 
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceLineStringGeometry3D(const LineString &gA, const Geometry &gB) -> double
 {
@@ -239,6 +269,14 @@ distanceLineStringGeometry3D(const LineString &gA, const Geometry &gB) -> double
   case TYPE_POLYGON:
     return distanceLineStringPolygon3D(gA, gB.as<Polygon>());
 
+  case TYPE_POLYHEDRALSURFACE:
+    return distanceLineStringPolyhedralSurface3D(gA,
+                                                 gB.as<PolyhedralSurface>());
+
+  case TYPE_TRIANGULATEDSURFACE:
+    return distanceLineStringTriangulatedSurface3D(
+        gA, gB.as<TriangulatedSurface>());
+
   case TYPE_SOLID:
     return distanceLineStringSolid3D(gA, gB.as<Solid>());
 
@@ -247,8 +285,6 @@ distanceLineStringGeometry3D(const LineString &gA, const Geometry &gB) -> double
   case TYPE_MULTIPOLYGON:
   case TYPE_MULTISOLID:
   case TYPE_GEOMETRYCOLLECTION:
-  case TYPE_TRIANGULATEDSURFACE:
-  case TYPE_POLYHEDRALSURFACE:
     return distanceGeometryCollectionToGeometry3D(gB, gA);
   }
 
@@ -258,9 +294,6 @@ distanceLineStringGeometry3D(const LineString &gA, const Geometry &gB) -> double
                     .str()));
 }
 
-///
-///
-///
 auto
 distanceLineStringLineString3D(const LineString &gA, const LineString &gB)
     -> double
@@ -285,9 +318,6 @@ distanceLineStringLineString3D(const LineString &gA, const LineString &gB)
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceLineStringTriangle3D(const LineString &gA, const Triangle &gB) -> double
 {
@@ -309,9 +339,6 @@ distanceLineStringTriangle3D(const LineString &gA, const Triangle &gB) -> double
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceLineStringPolygon3D(const LineString &gA, const Polygon &gB) -> double
 {
@@ -321,12 +348,55 @@ distanceLineStringPolygon3D(const LineString &gA, const Polygon &gB) -> double
 
   TriangulatedSurface triangulateSurfaceB;
   triangulate::triangulatePolygon3D(gB, triangulateSurfaceB);
-  return distanceGeometryCollectionToGeometry3D(triangulateSurfaceB, gA);
+  return distanceLineStringTriangulatedSurface3D(gA, triangulateSurfaceB);
+}
+
+auto
+distanceLineStringPolyhedralSurface3D(const LineString        &lineA,
+                                      const PolyhedralSurface &polySurfaceB)
+    -> double
+{
+  if (lineA.isEmpty() || polySurfaceB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects(lineA, polySurfaceB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < polySurfaceB.numPatches(); i++) {
+    dMin = std::min(dMin,
+                    distancePolygonGeometry3D(polySurfaceB.patchN(i), lineA));
+  }
+
+  return dMin;
+}
+
+auto
+distanceLineStringTriangulatedSurface3D(
+    const LineString &lineA, const TriangulatedSurface &triangulatedSurfaceB)
+    -> double
+{
+  if (lineA.isEmpty() || triangulatedSurfaceB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects(lineA, triangulatedSurfaceB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < triangulatedSurfaceB.numPatches(); i++) {
+    dMin = std::min(
+        dMin, distancePolygonGeometry3D(triangulatedSurfaceB.patchN(i), lineA));
+  }
+
+  return dMin;
 }
 
-///
-///
-///
 auto
 distanceLineStringSolid3D(const LineString &gA, const Solid &gB) -> double
 {
@@ -341,15 +411,13 @@ distanceLineStringSolid3D(const LineString &gA, const Solid &gB) -> double
   double dMin = std::numeric_limits<double>::infinity();
 
   for (size_t i = 0; i < gB.numShells(); i++) {
-    dMin = std::min(dMin, gB.shellN(i).distance3D(gA));
+    dMin =
+        std::min(dMin, distanceLineStringPolyhedralSurface3D(gA, gB.shellN(i)));
   }
 
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceTriangleGeometry3D(const Triangle &gA, const Geometry &gB) -> double
 {
@@ -369,6 +437,14 @@ distanceTriangleGeometry3D(const Triangle &gA, const Geometry &gB) -> double
   case TYPE_POLYGON:
     return distancePolygonGeometry3D(gB.as<Polygon>(), gA);
 
+  case TYPE_POLYHEDRALSURFACE:
+    return distancePolyhedralSurfaceGeometry3D(gB.as<PolyhedralSurface>(),
+                                               gA); // symetric
+
+  case TYPE_TRIANGULATEDSURFACE:
+    return distanceTriangulatedSurfaceGeometry3D(gB.as<TriangulatedSurface>(),
+                                                 gA); // symetric
+
   case TYPE_SOLID:
     return distanceTriangleSolid3D(gA, gB.as<Solid>());
 
@@ -377,8 +453,6 @@ distanceTriangleGeometry3D(const Triangle &gA, const Geometry &gB) -> double
   case TYPE_MULTIPOLYGON:
   case TYPE_MULTISOLID:
   case TYPE_GEOMETRYCOLLECTION:
-  case TYPE_TRIANGULATEDSURFACE:
-  case TYPE_POLYHEDRALSURFACE:
     return distanceGeometryCollectionToGeometry3D(gB, gA);
   }
 
@@ -388,9 +462,50 @@ distanceTriangleGeometry3D(const Triangle &gA, const Geometry &gB) -> double
                     .str()));
 }
 
-///
-///
-///
+auto
+distanceTrianglePolyhedralSurface3D(const Triangle          &triangleA,
+                                    const PolyhedralSurface &polySurfaceB)
+    -> double
+{
+  if (triangleA.isEmpty() || polySurfaceB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects3D(triangleA, polySurfaceB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < polySurfaceB.numPatches(); i++) {
+    dMin = std::min(dMin, polySurfaceB.patchN(i).distance3D(triangleA));
+  }
+
+  return dMin;
+}
+
+auto
+distanceTriangleTriangulatedSurface3D(
+    const Triangle &triangleA, const TriangulatedSurface &triangulatedSurfaceB)
+    -> double
+{
+  if (triangleA.isEmpty() || triangulatedSurfaceB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects3D(triangleA, triangulatedSurfaceB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < triangulatedSurfaceB.numPatches(); i++) {
+    dMin = std::min(dMin, triangulatedSurfaceB.patchN(i).distance3D(triangleA));
+  }
+
+  return dMin;
+}
+
 auto
 distanceTriangleSolid3D(const Triangle &gA, const Solid &gB) -> double
 {
@@ -405,15 +520,13 @@ distanceTriangleSolid3D(const Triangle &gA, const Solid &gB) -> double
   double dMin = std::numeric_limits<double>::infinity();
 
   for (size_t i = 0; i < gB.numShells(); i++) {
-    dMin = std::min(dMin, gB.shellN(i).distance3D(gA));
+    dMin =
+        std::min(dMin, distanceTrianglePolyhedralSurface3D(gA, gB.shellN(i)));
   }
 
   return dMin;
 }
 
-///
-///
-///
 auto
 distancePolygonGeometry3D(const Polygon &gA, const Geometry &gB) -> double
 {
@@ -426,12 +539,53 @@ distancePolygonGeometry3D(const Polygon &gA, const Geometry &gB) -> double
 
   TriangulatedSurface triangulateSurfaceA;
   triangulate::triangulatePolygon3D(gA, triangulateSurfaceA);
-  return distanceGeometryCollectionToGeometry3D(triangulateSurfaceA, gB);
+  return distanceTriangulatedSurfaceGeometry3D(triangulateSurfaceA, gB);
+}
+
+auto
+distancePolyhedralSurfaceGeometry3D(const PolyhedralSurface &polySurfaceA,
+                                    const Geometry          &geomB) -> double
+{
+  if (polySurfaceA.isEmpty() || geomB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects(polySurfaceA, geomB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < polySurfaceA.numPatches(); i++) {
+    dMin = std::min(dMin,
+                    distancePolygonGeometry3D(polySurfaceA.patchN(i), geomB));
+  }
+
+  return dMin;
+}
+
+auto
+distanceTriangulatedSurfaceGeometry3D(
+    const TriangulatedSurface &triangulatedSurfaceA, const Geometry &geomB)
+    -> double
+{
+  if (triangulatedSurfaceA.isEmpty() || geomB.isEmpty()) {
+    return std::numeric_limits<double>::infinity();
+  }
+
+  if (intersects(triangulatedSurfaceA, geomB, NoValidityCheck())) {
+    return 0.0;
+  }
+
+  double dMin = std::numeric_limits<double>::infinity();
+
+  for (size_t i = 0; i < triangulatedSurfaceA.numPatches(); i++) {
+    dMin = std::min(dMin, triangulatedSurfaceA.patchN(i).distance3D(geomB));
+  }
+
+  return dMin;
 }
 
-///
-///
-///
 auto
 distanceSolidGeometry3D(const Solid &gA, const Geometry &gB) -> double
 {
@@ -451,6 +605,14 @@ distanceSolidGeometry3D(const Solid &gA, const Geometry &gB) -> double
   case TYPE_POLYGON:
     return distancePolygonGeometry3D(gB.as<Polygon>(), gA); // symetric
 
+  case TYPE_POLYHEDRALSURFACE:
+    return distancePolyhedralSurfaceGeometry3D(gB.as<PolyhedralSurface>(),
+                                               gA); // symetric
+
+  case TYPE_TRIANGULATEDSURFACE:
+    return distanceTriangulatedSurfaceGeometry3D(gB.as<TriangulatedSurface>(),
+                                                 gA); // symetric
+
   case TYPE_SOLID:
     return distanceSolidSolid3D(gA, gB.as<Solid>());
 
@@ -459,8 +621,6 @@ distanceSolidGeometry3D(const Solid &gA, const Geometry &gB) -> double
   case TYPE_MULTIPOLYGON:
   case TYPE_MULTISOLID:
   case TYPE_GEOMETRYCOLLECTION:
-  case TYPE_TRIANGULATEDSURFACE:
-  case TYPE_POLYHEDRALSURFACE:
     return distanceGeometryCollectionToGeometry3D(gB, gA);
   }
 
@@ -470,9 +630,6 @@ distanceSolidGeometry3D(const Solid &gA, const Geometry &gB) -> double
                     .str()));
 }
 
-///
-///
-///
 auto
 distanceSolidSolid3D(const Solid &gA, const Solid &gB) -> double
 {
@@ -543,8 +700,6 @@ boundingSphere(const Geometry &geom) -> const Sphere
     return Sphere();
   }
 
-  using Vector_3 = CGAL::Vector_3<Kernel>;
-
   const auto end = v.points.end();
 
   // centroid
@@ -576,9 +731,6 @@ boundingSphere(const Geometry &geom) -> const Sphere
   return Sphere(std::sqrt(CGAL::to_double(maxDistanceSq)), c);
 }
 
-///
-///
-///
 auto
 distanceGeometryCollectionToGeometry3D(const Geometry &gA, const Geometry &gB)
     -> double
@@ -663,9 +815,6 @@ distanceGeometryCollectionToGeometry3D(const Geometry &gA, const Geometry &gB)
   return dMin;
 }
 
-///
-///
-///
 auto
 distancePointSegment3D(const Point &p, const Point &a, const Point &b) -> double
 {
@@ -714,9 +863,6 @@ squaredDistancePointTriangle3D(const Point_3 &p, const Triangle_3 &abc)
 #endif
 }
 
-///
-///
-///
 auto
 distancePointTriangle3D(const Point &p_, const Point &a_, const Point &b_,
                         const Point &c_) -> double
@@ -734,9 +880,6 @@ distancePointTriangle3D(const Point &p_, const Point &a_, const Point &b_,
   return CGAL::sqrt(CGAL::to_double(dMin));
 }
 
-///
-///
-///
 auto
 distanceSegmentSegment3D(const Point &a, const Point &b, const Point &c,
                          const Point &d) -> double
@@ -783,9 +926,6 @@ squaredDistanceSegmentTriangle3D(const Segment_3 &sAB, const Triangle_3 &tABC)
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceSegmentTriangle3D(const Point &sA_, const Point &sB_, const Point &tA_,
                           const Point &tB_, const Point &tC_) -> double
@@ -848,9 +988,6 @@ squaredDistanceTriangleTriangle3D(const Triangle_3 &triangleA,
   return dMin;
 }
 
-///
-///
-///
 auto
 distanceTriangleTriangle3D(const Triangle &gA, const Triangle &gB) -> double
 {
@@ -866,4 +1003,6 @@ distanceTriangleTriangle3D(const Triangle &gA, const Triangle &gB) -> double
   return CGAL::sqrt(CGAL::to_double(dMin));
 }
 
-} // namespace SFCGAL::algorithm
+} // namespace algorithm
+} // namespace SFCGAL
+/// @} end of private section
