@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/algorithm/intersection.h"
@@ -23,11 +24,14 @@ using namespace SFCGAL::detail;
 
 namespace SFCGAL {
 
-using Point_2    = CGAL::Point_2<Kernel>;
-using Segment_2  = CGAL::Segment_2<Kernel>;
-using Triangle_2 = CGAL::Triangle_2<Kernel>;
-
 namespace algorithm {
+
+// ----------------------------------------------------------------------------------
+// -- private interface
+// ----------------------------------------------------------------------------------
+/// @{
+/// @privatesection
+
 // see Intersection3D.cpp
 void
 intersection(const PrimitiveHandle<3> &pa, const PrimitiveHandle<3> &pb,
@@ -122,6 +126,12 @@ post_intersection(const GeometrySet<3> &input, GeometrySet<3> &output)
   // nothing special to do
   output = input;
 }
+/// @} end of private section
+
+// ----------------------------------------------------------------------------------
+// -- public interface
+// ----------------------------------------------------------------------------------
+/// @publicsection
 
 template <int Dim>
 void
@@ -145,9 +155,11 @@ intersection(const GeometrySet<Dim> &a, const GeometrySet<Dim> &b,
   output.merge(temp2);
 }
 
+/// @private
 template void
 intersection<2>(const GeometrySet<2> &a, const GeometrySet<2> &b,
                 GeometrySet<2> &);
+/// @private
 template void
 intersection<3>(const GeometrySet<3> &a, const GeometrySet<3> &b,
                 GeometrySet<3> &);
