@@ -1,11 +1,12 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef SFCGAL_INTERSECTS_ALGORITHM
 #define SFCGAL_INTERSECTS_ALGORITHM
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
 namespace SFCGAL {
 class Geometry;
@@ -27,7 +28,6 @@ struct NoValidityCheck;
 /**
  * Robust intersection test on 2D geometries. Force projection to z=0 if needed
  * @pre ga and gb are valid geometries
- * @ingroup public_api
  */
 SFCGAL_API bool
 intersects(const Geometry &ga, const Geometry &gb);
@@ -35,7 +35,6 @@ intersects(const Geometry &ga, const Geometry &gb);
 /**
  * Robust intersection test on 3D geometries. Assume z = 0 if needed
  * @pre ga and gb are valid geometries
- * @ingroup public_api
  */
 SFCGAL_API bool
 intersects3D(const Geometry &ga, const Geometry &gb);
