@@ -1,13 +1,14 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_NORMAL_H_
-#define _SFCGAL_ALGORITHM_NORMAL_H_
+#ifndef SFCGAL_ALGORITHM_NORMAL_H_
+#define SFCGAL_ALGORITHM_NORMAL_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/Polygon.h>
+#include "SFCGAL/Polygon.h"
 
 namespace SFCGAL {
 namespace algorithm {
