@@ -1,5 +1,7 @@
-// Copyright (c) 2023-2023, Oslandia.
+// Copyright (c) 2023-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
+
 #include "SFCGAL/algorithm/visibility.h"
 #include "SFCGAL/Polygon.h"
 
@@ -16,9 +18,12 @@
 
 namespace SFCGAL::algorithm {
 
-using Point_2               = Kernel::Point_2;
-using Polygon_2             = CGAL::Polygon_2<Kernel>;
-using Segment_2             = Kernel::Segment_2;
+// ----------------------------------------------------------------------------------
+// -- private interface
+// ----------------------------------------------------------------------------------
+/// @{
+/// @privatesection
+
 using Traits_2              = CGAL::Arr_segment_traits_2<Kernel>;
 using Arrangement_2         = CGAL::Arrangement_2<Traits_2>;
 using Face_handle           = Arrangement_2::Face_handle;
@@ -26,7 +31,6 @@ using Face_const_handle     = Arrangement_2::Face_const_handle;
 using Halfedge_const_handle = Arrangement_2::Halfedge_const_handle;
 using TEV =
     CGAL::Triangular_expansion_visibility_2<Arrangement_2, CGAL::Tag_true>;
-using PolygonWithHoles = CGAL::Polygon_with_holes_2<Kernel>;
 
 static auto
 query_visibility(Face_handle fh, Halfedge_const_handle he)
@@ -62,9 +66,13 @@ query_visibility(Face_handle fh, Halfedge_const_handle he)
   return result;
 }
 
-///
-///
-///
+/// @} end of private section
+
+// ----------------------------------------------------------------------------------
+// -- public interface
+// ----------------------------------------------------------------------------------
+/// @publicsection
+
 auto
 visibility(const Geometry &polygon, const Geometry &point)
     -> std::unique_ptr<Polygon>
@@ -82,6 +90,10 @@ visibility(const Geometry &polygon, const Geometry &point,
            NoValidityCheck /*unused*/) -> std::unique_ptr<Polygon>
 {
 
+  if (polygon.isEmpty() || point.isEmpty()) {
+    return std::make_unique<Polygon>();
+  }
+
   Point_2 const                     queryPoint{point.as<Point>().toPoint_2()};
   std::unique_ptr<LineString> const extRing{new LineString()};
 
@@ -174,9 +186,6 @@ visibility(const Geometry &polygon, const Geometry &point,
 
   return query_visibility(fh, fh->outer_ccb());
 }
-///
-///
-///
 auto
 visibility(const Geometry &polygon, const Geometry &pointA,
            const Geometry &pointB) -> std::unique_ptr<Polygon>
@@ -195,6 +204,10 @@ visibility(const Geometry &polygon, const Geometry &pointA,
     -> std::unique_ptr<Polygon>
 {
 
+  if (polygon.isEmpty() || pointA.isEmpty() || pointB.isEmpty()) {
+    return std::make_unique<Polygon>();
+  }
+
   Point_2 const startPoint{pointA.as<Point>().toPoint_2()};
   Point_2 const endPoint{pointB.as<Point>().toPoint_2()};
   Point_2 const queryPoint{pointB.as<Point>().toPoint_2()};
