@@ -1,9 +1,10 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_ALGORITHM_VOLUME_H_
-#define _SFCGAL_ALGORITHM_VOLUME_H_
+#ifndef SFCGAL_ALGORITHM_VOLUME_H_
+#define SFCGAL_ALGORITHM_VOLUME_H_
 
 #include "SFCGAL/Geometry.h"
 #include "SFCGAL/Kernel.h"
@@ -17,7 +18,6 @@ struct NoValidityCheck;
 /**
  * Computes the volume of a geometry
  * @pre g is a valid Geometry
- * @ingroup public_api
  */
 SFCGAL_API const Kernel::FT
                  volume(const Geometry &g);
@@ -25,7 +25,6 @@ SFCGAL_API const Kernel::FT
 /**
  * Computes the volume of a Solid
  * @pre (not checked) volume is closed and consistently oriented
- * @ingroup detail
  */
 SFCGAL_API const Kernel::FT
                  volume(const Solid &g, NoValidityCheck);
