@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/detail/ForceValidityVisitor.h"
@@ -19,18 +20,12 @@
 
 namespace SFCGAL::detail {
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(Point &g)
 {
   g.forceValidityFlag(valid_);
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(LineString &g)
 {
@@ -40,9 +35,6 @@ ForceValidityVisitor::visit(LineString &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(Polygon &g)
 {
@@ -52,9 +44,6 @@ ForceValidityVisitor::visit(Polygon &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(Triangle &g)
 {
@@ -64,9 +53,6 @@ ForceValidityVisitor::visit(Triangle &g)
   visit(g.vertex(2));
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(Solid &g)
 {
@@ -76,9 +62,6 @@ ForceValidityVisitor::visit(Solid &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(MultiPoint &g)
 {
@@ -88,9 +71,6 @@ ForceValidityVisitor::visit(MultiPoint &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(MultiLineString &g)
 {
@@ -100,9 +80,6 @@ ForceValidityVisitor::visit(MultiLineString &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(MultiPolygon &g)
 {
@@ -112,9 +89,6 @@ ForceValidityVisitor::visit(MultiPolygon &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(MultiSolid &g)
 {
@@ -124,9 +98,6 @@ ForceValidityVisitor::visit(MultiSolid &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(GeometryCollection &g)
 {
@@ -136,27 +107,21 @@ ForceValidityVisitor::visit(GeometryCollection &g)
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(PolyhedralSurface &g)
 {
   g.forceValidityFlag(valid_);
-  for (size_t i = 0; i < g.numPolygons(); i++) {
-    visit(g.polygonN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    visit(g.patchN(i));
   }
 }
 
-///
-///
-///
 void
 ForceValidityVisitor::visit(TriangulatedSurface &g)
 {
   g.forceValidityFlag(valid_);
-  for (size_t i = 0; i < g.numGeometries(); i++) {
-    visit(g.geometryN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    visit(g.patchN(i));
   }
 }
 
