@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/detail/GeometrySet.h"
@@ -98,8 +99,8 @@ _decompose_polygon(const Polygon                     &poly,
   TriangulatedSurface surf;
   triangulate::triangulatePolygon3D(poly, surf);
 
-  for (size_t i = 0; i < surf.numTriangles(); ++i) {
-    const Triangle &tri = surf.triangleN(i);
+  for (size_t i = 0; i < surf.numPatches(); ++i) {
+    const Triangle &tri = surf.patchN(i);
     surfaces.emplace_back(CGAL::Triangle_3<Kernel>(tri.vertex(0).toPoint_3(),
                                                    tri.vertex(1).toPoint_3(),
                                                    tri.vertex(2).toPoint_3()));
@@ -507,8 +508,8 @@ GeometrySet<Dim>::_decompose(const Geometry &g)
   case TYPE_TRIANGULATEDSURFACE: {
     const auto &tri = g.as<TriangulatedSurface>();
 
-    for (size_t i = 0; i < tri.numTriangles(); ++i) {
-      _decompose(tri.triangleN(i));
+    for (size_t i = 0; i < tri.numPatches(); ++i) {
+      _decompose(tri.patchN(i));
     }
 
     break;
@@ -517,8 +518,8 @@ GeometrySet<Dim>::_decompose(const Geometry &g)
   case TYPE_POLYHEDRALSURFACE: {
     const auto &tri = g.as<PolyhedralSurface>();
 
-    for (size_t i = 0; i < tri.numPolygons(); ++i) {
-      _decompose(tri.polygonN(i));
+    for (size_t i = 0; i < tri.numPatches(); ++i) {
+      _decompose(tri.patchN(i));
     }
 
     break;
@@ -727,12 +728,12 @@ recompose_surfaces(const GeometrySet<3>::SurfaceCollection &surfaces,
   std::unique_ptr<TriangulatedSurface> tri(new TriangulatedSurface);
 
   for (const auto &surface : surfaces) {
-    tri->addTriangle(new Triangle(surface.primitive()));
+    tri->addPatch(new Triangle(surface.primitive()));
   }
 
   algorithm::SurfaceGraph const graph(*tri);
   std::vector<size_t> component(boost::num_vertices(graph.faceGraph()));
-  BOOST_ASSERT(tri->numTriangles() == component.size());
+  BOOST_ASSERT(tri->numPatches() == component.size());
   const size_t numComponents =
       boost::connected_components(graph.faceGraph(), component.data());
 
@@ -746,10 +747,10 @@ recompose_surfaces(const GeometrySet<3>::SurfaceCollection &surfaces,
       output.push_back(sout[c]);
     }
 
-    const size_t numTriangles = tri->numTriangles();
+    const size_t numPatches = tri->numPatches();
 
-    for (size_t t = 0; t != numTriangles; ++t) {
-      sout[component[t]]->addTriangle(tri->triangleN(t));
+    for (size_t t = 0; t != numPatches; ++t) {
+      sout[component[t]]->addPatch(tri->patchN(t));
     }
   }
 }
