@@ -1,9 +1,10 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_DETAIL_GEOMETRY_SET_H_
-#define _SFCGAL_DETAIL_GEOMETRY_SET_H_
+#ifndef SFCGAL_DETAIL_GEOMETRY_SET_H_
+#define SFCGAL_DETAIL_GEOMETRY_SET_H_
 
 #include <boost/ptr_container/ptr_vector.hpp>
 #include <boost/variant.hpp>
@@ -17,10 +18,12 @@
 #include <CGAL/Bbox_3.h>
 #include <CGAL/Box_intersection_d/Box_with_handle_d.h>
 
-// comparison operator on segments, for use in a std::set
+/// comparison operator on 2D segments, for use in a std::set
 bool
 operator<(const CGAL::Segment_2<SFCGAL::Kernel> &sega,
           const CGAL::Segment_2<SFCGAL::Kernel> &segb);
+
+/// comparison operator on 3D segments, for use in a std::set
 bool
 operator<(const CGAL::Segment_3<SFCGAL::Kernel> &sega,
           const CGAL::Segment_3<SFCGAL::Kernel> &segb);
@@ -29,7 +32,6 @@ namespace SFCGAL {
 class Geometry;
 namespace detail {
 
-///
 /// Primitive type enumeration. Note that the value is the dimension !
 enum PrimitiveType {
   PrimitivePoint   = 0,
@@ -38,7 +40,6 @@ enum PrimitiveType {
   PrimitiveVolume  = 3
 };
 
-///
 /// Primitive handle. Holds a pointer to a primitive, through the 'handle'
 /// member
 template <int Dim>
@@ -65,7 +66,6 @@ struct PrimitiveHandle {
   }
 };
 
-///
 /// PrimitiveBox. Type used for CGAL::Box_intersection_d
 template <int Dim>
 struct PrimitiveBox {
@@ -74,21 +74,18 @@ struct PrimitiveBox {
       Type;
 };
 
-///
 /// BoxCollection for use with CGAL::Box_intersection_d
 template <int Dim>
 struct BoxCollection {
   typedef std::vector<typename PrimitiveBox<Dim>::Type> Type;
 };
 
-///
 /// HandleCollection. Used to store PrimitiveHandle
 template <int Dim>
 struct HandleCollection {
   typedef std::list<PrimitiveHandle<Dim>> Type;
 };
 
-///
 /// Flags available for each type of Geometry type.
 /// Primitives can be 'flagged' in order to speed up recomposition
 enum ElementFlag {
@@ -96,7 +93,6 @@ enum ElementFlag {
   FLAG_IS_PLANAR = 1
 };
 
-///
 /// CollectionElement, a Primitive with flags
 /// Primitive : Point_d, Segment_d, Surface_d, Volume_d
 template <class Primitive>
@@ -152,7 +148,6 @@ operator<<(std::ostream &ostr, const CollectionElement<Primitive> &p)
   return ostr;
 }
 
-///
 /// A GeometrySet represents a set of CGAL primitives.
 /// Primitive are either of dimension 0 (points),
 /// dimension 1 (segments), dimension 2 (surfaces, a.k.a. polygon or triangles)
@@ -396,11 +391,9 @@ private:
   VolumeCollection  _volumes;
 };
 
-///
 /// Display operator
 SFCGAL_API std::ostream            &
 operator<<(std::ostream &, const GeometrySet<2> &g);
-///
 /// Display operator
 SFCGAL_API std::ostream            &
 operator<<(std::ostream &, const GeometrySet<3> &g);
