@@ -1,36 +1,31 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <SFCGAL/detail/GetPointsVisitor.h>
+#include "SFCGAL/detail/GetPointsVisitor.h"
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
 
 namespace SFCGAL::detail {
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const Point &g)
 {
   points.push_back(&g);
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const LineString &g)
 {
@@ -39,9 +34,6 @@ GetPointsVisitor::visit(const LineString &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const Polygon &g)
 {
@@ -50,9 +42,6 @@ GetPointsVisitor::visit(const Polygon &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const Triangle &g)
 {
@@ -61,9 +50,6 @@ GetPointsVisitor::visit(const Triangle &g)
   visit(g.vertex(2));
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const Solid &g)
 {
@@ -72,9 +58,6 @@ GetPointsVisitor::visit(const Solid &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const MultiPoint &g)
 {
@@ -83,9 +66,6 @@ GetPointsVisitor::visit(const MultiPoint &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const MultiLineString &g)
 {
@@ -94,9 +74,6 @@ GetPointsVisitor::visit(const MultiLineString &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const MultiPolygon &g)
 {
@@ -105,9 +82,6 @@ GetPointsVisitor::visit(const MultiPolygon &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const MultiSolid &g)
 {
@@ -116,9 +90,6 @@ GetPointsVisitor::visit(const MultiSolid &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const GeometryCollection &g)
 {
@@ -127,25 +98,19 @@ GetPointsVisitor::visit(const GeometryCollection &g)
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const PolyhedralSurface &g)
 {
-  for (size_t i = 0; i < g.numPolygons(); i++) {
-    visit(g.polygonN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    visit(g.patchN(i));
   }
 }
 
-///
-///
-///
 void
 GetPointsVisitor::visit(const TriangulatedSurface &g)
 {
-  for (size_t i = 0; i < g.numGeometries(); i++) {
-    visit(g.geometryN(i));
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    visit(g.patchN(i));
   }
 }
 
