@@ -1,11 +1,12 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_GENERATOR_DISC_H_
-#define _SFCGAL_GENERATOR_DISC_H_
+#ifndef SFCGAL_GENERATOR_DISC_H_
+#define SFCGAL_GENERATOR_DISC_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
 #include <memory>
 
