@@ -1,23 +1,24 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/config.h"
 #ifdef SFCGAL_WITH_OSG
 
-#include "SFCGAL/detail/io/OsgFactory.h"
+  #include "SFCGAL/detail/io/OsgFactory.h"
 
-#include "SFCGAL/GeometryCollection.h"
-#include "SFCGAL/LineString.h"
-#include "SFCGAL/Point.h"
-#include "SFCGAL/Polygon.h"
-#include "SFCGAL/PolyhedralSurface.h"
-#include "SFCGAL/Solid.h"
-#include "SFCGAL/Triangle.h"
-#include "SFCGAL/TriangulatedSurface.h"
+  #include "SFCGAL/GeometryCollection.h"
+  #include "SFCGAL/LineString.h"
+  #include "SFCGAL/Point.h"
+  #include "SFCGAL/Polygon.h"
+  #include "SFCGAL/PolyhedralSurface.h"
+  #include "SFCGAL/Solid.h"
+  #include "SFCGAL/Triangle.h"
+  #include "SFCGAL/TriangulatedSurface.h"
 
-#include "SFCGAL/Exception.h"
-#include "SFCGAL/triangulate/triangulatePolygon.h"
+  #include "SFCGAL/Exception.h"
+  #include "SFCGAL/triangulate/triangulatePolygon.h"
 
 namespace SFCGAL {
 namespace detail {
@@ -124,8 +125,8 @@ OsgFactory::addToGeometry(osg::Geometry *geometry, const TriangulatedSurface &g)
 
   size_t start = vertices->size();
 
-  for (size_t i = 0; i < g.numGeometries(); i++) {
-    const Triangle &triangle = g.geometryN(i);
+  for (size_t i = 0; i < g.numPatches(); i++) {
+    const Triangle &triangle = g.patchN(i);
 
     osg::Vec3 a = createVec3(triangle.vertex(0));
     osg::Vec3 b = createVec3(triangle.vertex(1));
@@ -147,7 +148,7 @@ OsgFactory::addToGeometry(osg::Geometry *geometry, const TriangulatedSurface &g)
 
   geometry->setNormalBinding(osg::Geometry::BIND_PER_VERTEX);
   geometry->addPrimitiveSet(new osg::DrawArrays(osg::PrimitiveSet::TRIANGLES,
-                                                start, g.numGeometries() * 3));
+                                                start, g.numPatches() * 3));
 }
 
 void
@@ -186,9 +187,6 @@ OsgFactory::addToGeometry(osg::Geometry *geometry, const GeometryCollection &g)
     addToGeometry(geometry, g.geometryN(i));
   }
 }
-///
-///
-///
 osg::Geometry *
 OsgFactory::createGeometry(const Geometry &g)
 {
@@ -204,9 +202,6 @@ OsgFactory::createGeometry(const Geometry &g)
   return geometry.release();
 }
 
-///
-///
-///
 osg::Vec3
 OsgFactory::createVec3(const Point &g) const
 {
@@ -214,18 +209,12 @@ OsgFactory::createVec3(const Point &g) const
                    CGAL::to_double(g.z()));
 }
 
-///
-///
-///
 size_t
 OsgFactory::createVertex(osg::Vec3Array *vertices, const Point &g)
 {
   return createVertex(vertices, createVec3(g));
 }
 
-///
-///
-///
 size_t
 OsgFactory::createVertex(osg::Vec3Array *vertices, const osg::Vec3 &g)
 {
