@@ -1,4 +1,5 @@
-// Copyright (c) 2023-2023, Oslandia.
+// Copyright (c) 2023-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef SFCGAL_IO_WKBREADER_H_
@@ -229,7 +230,7 @@ private:
 
     default:
       std::ostringstream oss;
-      oss << "WkbWriter: type '" << geometryType << "' is not supported";
+      oss << "WkbReader: type '" << geometryType << "' is not supported";
       std::cerr << oss.str() << std::endl;
 
       return {};
