@@ -1,4 +1,5 @@
-// Copyright (c) 2023-2023, Oslandia.
+// Copyright (c) 2023-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <array>
@@ -7,6 +8,7 @@
 
 #include "SFCGAL/detail/io/WkbWriter.h"
 
+#include "SFCGAL/Exception.h"
 #include "SFCGAL/GeometryCollection.h"
 #include "SFCGAL/LineString.h"
 #include "SFCGAL/MultiLineString.h"
@@ -23,9 +25,6 @@
 
 namespace SFCGAL::detail::io {
 
-///
-///
-///
 void
 WkbWriter::writeRec(const Geometry &g, boost::endian::order wkbOrder)
 {
@@ -63,18 +62,17 @@ WkbWriter::writeRec(const Geometry &g, boost::endian::order wkbOrder)
     return;
 
   case TYPE_TRIANGULATEDSURFACE:
-    writeInner<TriangulatedSurface, Triangle>(g.as<TriangulatedSurface>(),
-                                              wkbOrder);
+    writeInner(g.as<TriangulatedSurface>(), wkbOrder);
     return;
 
   case TYPE_POLYHEDRALSURFACE:
-    writeInner<PolyhedralSurface, Polygon>(g.as<PolyhedralSurface>(), wkbOrder);
+    writeInner(g.as<PolyhedralSurface>(), wkbOrder);
     return;
 
   default:
     std::ostringstream oss;
     oss << "WkbWriter: type '" << g.geometryType() << "' is not supported";
-    BOOST_THROW_EXCEPTION(std::runtime_error(oss.str()));
+    BOOST_THROW_EXCEPTION(InappropriateGeometryException(oss.str()));
   }
 }
 
@@ -90,18 +88,12 @@ WkbWriter::write(const Geometry &g, const srid_t &srid,
   write(g, wkbOrder);
 }
 
-///
-///
-///
 void
 WkbWriter::write(const Geometry &g, boost::endian::order wkbOrder)
 {
   writeRec(g, wkbOrder);
 }
 
-///
-///
-///
 void
 WkbWriter::writeCoordinate(const Point &g, boost::endian::order wkbOrder)
 {
@@ -157,9 +149,6 @@ WkbWriter::writeGeometryType(const Geometry &g, boost::endian::order wkbOrder)
   }
 }
 
-///
-///
-///
 void
 WkbWriter::writeInner(const Point &g, boost::endian::order wkbOrder)
 {
@@ -183,9 +172,6 @@ WkbWriter::writeInner(const Point &g, boost::endian::order wkbOrder)
   }
 }
 
-///
-///
-///
 void
 WkbWriter::writeInner(const LineString &g, boost::endian::order wkbOrder)
 {
@@ -207,9 +193,6 @@ WkbWriter::writeInnerRing(const LineString &g, boost::endian::order wkbOrder)
   }
 }
 
-///
-///
-///
 void
 WkbWriter::writeInner(const Polygon &g, boost::endian::order wkbOrder)
 {
@@ -227,9 +210,6 @@ WkbWriter::writeInner(const Polygon &g, boost::endian::order wkbOrder)
   }
 }
 
-///
-///
-///
 void
 WkbWriter::writeInner(const Triangle &g, boost::endian::order wkbOrder)
 {
@@ -268,6 +248,42 @@ WkbWriter::writeInner(const GeometryCollection &g,
   }
 }
 
+void
+WkbWriter::writeInner(const PolyhedralSurface &polyhedralSurface,
+                      boost::endian::order     wkbOrder)
+{
+  // Endianness
+  toStream(std::array<std::byte, 1>{static_cast<std::byte>(wkbOrder)});
+
+  // WkbType
+  writeGeometryType(polyhedralSurface, wkbOrder);
+
+  // Number of Polygons
+  toByte(static_cast<uint32_t>(polyhedralSurface.numPatches()), wkbOrder);
+
+  for (size_t i = 0; i < polyhedralSurface.numPatches(); i++) {
+    writeRec(polyhedralSurface.patchN(i), wkbOrder);
+  }
+}
+
+void
+WkbWriter::writeInner(const TriangulatedSurface &triangulatedSurface,
+                      boost::endian::order       wkbOrder)
+{
+  // Endianness
+  toStream(std::array<std::byte, 1>{static_cast<std::byte>(wkbOrder)});
+
+  // WkbType
+  writeGeometryType(triangulatedSurface, wkbOrder);
+
+  // Number of Triangles
+  toByte(static_cast<uint32_t>(triangulatedSurface.numPatches()), wkbOrder);
+
+  for (size_t i = 0; i < triangulatedSurface.numPatches(); i++) {
+    writeRec(triangulatedSurface.patchN(i), wkbOrder);
+  }
+}
+
 template <typename M, typename G>
 void
 WkbWriter::writeInner(const M &g, boost::endian::order wkbOrder)
