@@ -1,4 +1,5 @@
-// Copyright (c) 2023-2023, Oslandia.
+// Copyright (c) 2023-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #ifndef SFCGAL_IO_WKBWRITER_H_
@@ -13,8 +14,6 @@
 #include "SFCGAL/Geometry.h"
 #include "SFCGAL/config.h"
 
-using srid_t = uint32_t;
-
 namespace SFCGAL::detail::io {
 
 /**
@@ -24,7 +23,7 @@ namespace SFCGAL::detail::io {
 class SFCGAL_API WkbWriter {
 public:
   WkbWriter(std::ostream &s, bool asHexString = false)
-      : _s(s), _asHexString(asHexString){};
+      : _s(s), _asHexString(asHexString) {};
 
   /**
    * write WKB for a geometry
@@ -86,10 +85,23 @@ private:
   writeInner(const GeometryCollection &g,
              boost::endian::order      wkbOrder = boost::endian::order::native);
 
+  /**
+   * Dedicated method to write PolyhedralSurface into _wkb data
+   */
+  void
+  writeInner(const PolyhedralSurface &polyhedralSurface,
+             boost::endian::order     wkbOrder = boost::endian::order::native);
+
+  /**
+   * Dedicated method to write TriangulatedSurface into _wkb data
+   */
+  void
+  writeInner(const TriangulatedSurface &triangulatedSurface,
+             boost::endian::order wkbOrder = boost::endian::order::native);
+
   /**
    * Dedicated method to write Multi Geometries into _wkb data
-   * Multi Geometries are: MultiPoint, MultiLineString, MultiPolygon,
-   * PolyhedralSurface and TriangulatedSurface.
+   * Multi Geometries are: MultiPoint, MultiLineString, MultiPolygon.
    */
   template <typename M, typename G>
   void
