@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/detail/transform/AffineTransform3.h"
@@ -24,17 +25,11 @@
 
 namespace SFCGAL::transform {
 
-///
-///
-///
 AffineTransform3::AffineTransform3(CGAL::Aff_transformation_3<Kernel> transform)
     : _transform(std::move(transform))
 {
 }
 
-///
-///
-///
 void
 AffineTransform3::transform(Point &p)
 {
@@ -47,9 +42,6 @@ AffineTransform3::transform(Point &p)
   }
 }
 
-///
-///
-///
 void
 AffineTransform3::transform(LineString &ls)
 {
@@ -58,9 +50,6 @@ AffineTransform3::transform(LineString &ls)
   }
 }
 
-///
-///
-///
 void
 AffineTransform3::transform(Triangle &tri)
 {
@@ -69,9 +58,6 @@ AffineTransform3::transform(Triangle &tri)
   transform(tri.vertex(2));
 }
 
-///
-///
-///
 void
 AffineTransform3::transform(Polygon &poly)
 {
@@ -82,31 +68,22 @@ AffineTransform3::transform(Polygon &poly)
   }
 }
 
-///
-///
-///
 void
 AffineTransform3::transform(PolyhedralSurface &surf)
 {
-  for (size_t i = 0; i < surf.numPolygons(); ++i) {
-    transform(surf.polygonN(i));
+  for (size_t i = 0; i < surf.numPatches(); ++i) {
+    transform(surf.patchN(i));
   }
 }
 
-///
-///
-///
 void
 AffineTransform3::transform(TriangulatedSurface &surf)
 {
-  for (size_t i = 0; i < surf.numGeometries(); ++i) {
-    transform(surf.geometryN(i));
+  for (size_t i = 0; i < surf.numPatches(); ++i) {
+    transform(surf.patchN(i));
   }
 }
 
-///
-///
-///
 void
 AffineTransform3::transform(Solid &solid)
 {
