@@ -1,9 +1,10 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_TRANSFORM_AFFINETRANSFORM3_H_
-#define _SFCGAL_TRANSFORM_AFFINETRANSFORM3_H_
+#ifndef SFCGAL_TRANSFORM_AFFINETRANSFORM3_H_
+#define SFCGAL_TRANSFORM_AFFINETRANSFORM3_H_
 
 #include "SFCGAL/Kernel.h"
 #include "SFCGAL/Transform.h"
@@ -28,8 +29,8 @@ public:
   /*
    * [SFCGAL::Transform]
    */
-  virtual void
-  transform(Point &p);
+  void
+  transform(Point &p) override;
 
   virtual void
   transform(LineString &ls);
