@@ -1,9 +1,10 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_TRIANGULATE_DETAIL_MARKDOMAINS_H_
-#define _SFCGAL_TRIANGULATE_DETAIL_MARKDOMAINS_H_
+#ifndef SFCGAL_TRIANGULATE_DETAIL_MARKDOMAINS_H_
+#define SFCGAL_TRIANGULATE_DETAIL_MARKDOMAINS_H_
 
 namespace SFCGAL {
 namespace triangulate {
