@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/io/ewkt.h"
@@ -11,12 +12,10 @@
 #include <memory>
 
 using namespace SFCGAL::detail::io;
+using namespace SFCGAL::tools;
 
 namespace SFCGAL::io {
 
-///
-///
-///
 auto
 readEwkt(std::istream &s) -> std::unique_ptr<PreparedGeometry>
 {
@@ -28,9 +27,6 @@ readEwkt(std::istream &s) -> std::unique_ptr<PreparedGeometry>
   return uptr;
 }
 
-///
-///
-///
 auto
 readEwkt(const std::string &s) -> std::unique_ptr<PreparedGeometry>
 {
@@ -41,9 +37,6 @@ readEwkt(const std::string &s) -> std::unique_ptr<PreparedGeometry>
   return std::make_unique<PreparedGeometry>(std::move(g), srid);
 }
 
-///
-///
-///
 auto
 readEwkt(const char *str, size_t len) -> std::unique_ptr<PreparedGeometry>
 {
