@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2023, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/io/wkb.h"
@@ -10,12 +11,10 @@
 #include "SFCGAL/detail/tools/CharArrayBuffer.h"
 
 using namespace SFCGAL::detail::io;
+using namespace SFCGAL::tools;
 
 namespace SFCGAL::io {
 
-///
-///
-///
 auto
 readWkb(std::istream &stream, bool asHexString) -> std::unique_ptr<Geometry>
 {
@@ -24,9 +23,6 @@ readWkb(std::istream &stream, bool asHexString) -> std::unique_ptr<Geometry>
   return wkbReader.geometry();
 }
 
-///
-///
-///
 auto
 readWkb(const std::string &s, bool asHexString) -> std::unique_ptr<Geometry>
 {
@@ -36,9 +32,6 @@ readWkb(const std::string &s, bool asHexString) -> std::unique_ptr<Geometry>
   return wkbReader.geometry();
 }
 
-///
-///
-///
 auto
 readWkb(const char *str, size_t len, bool asHexString)
     -> std::unique_ptr<Geometry>
