@@ -1,5 +1,6 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "SFCGAL/io/wkt.h"
@@ -10,12 +11,10 @@
 #include "SFCGAL/detail/tools/CharArrayBuffer.h"
 
 using namespace SFCGAL::detail::io;
+using namespace SFCGAL::tools;
 
 namespace SFCGAL::io {
 
-///
-///
-///
 auto
 readWkt(std::istream &s) -> std::unique_ptr<Geometry>
 {
@@ -23,9 +22,6 @@ readWkt(std::istream &s) -> std::unique_ptr<Geometry>
   return std::unique_ptr<Geometry>(wktReader.readGeometry());
 }
 
-///
-///
-///
 auto
 readWkt(const std::string &s) -> std::unique_ptr<Geometry>
 {
@@ -41,9 +37,6 @@ readWkt(const std::string &s) -> std::unique_ptr<Geometry>
   return geom;
 }
 
-///
-///
-///
 auto
 readWkt(const char *str, size_t len) -> std::unique_ptr<Geometry>
 {
