@@ -1,14 +1,15 @@
 // Copyright (c) 2012-2013, IGN France.
-// Copyright (c) 2012-2022, Oslandia.
-// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
-#ifndef _SFCGAL_TRIANGULATE_TRIANGULATE2DZ_H_
-#define _SFCGAL_TRIANGULATE_TRIANGULATE2DZ_H_
+#ifndef SFCGAL_TRIANGULATE_TRIANGULATE2DZ_H_
+#define SFCGAL_TRIANGULATE_TRIANGULATE2DZ_H_
 
-#include <SFCGAL/config.h>
+#include "SFCGAL/config.h"
 
-#include <SFCGAL/Geometry.h>
-#include <SFCGAL/detail/triangulate/ConstraintDelaunayTriangulation.h>
+#include "SFCGAL/Geometry.h"
+#include "SFCGAL/detail/triangulate/ConstraintDelaunayTriangulation.h"
 
 namespace SFCGAL {
 namespace triangulate {
@@ -18,6 +19,7 @@ namespace triangulate {
  */
 SFCGAL_API void
 triangulate2DZ(const Geometry &g, ConstraintDelaunayTriangulation &triangulate);
+
 /**
  * @brief Constraint 2DZ Delaunay Triangulation (keep Z if defined, project
  * points in OXY plane)
