@@ -1,50 +1,35 @@
-/**
- *   SFCGAL
- *
- *   Copyright (C) 2012-2013 Oslandia <infos@oslandia.com>
- *   Copyright (C) 2012-2013 IGN (http://www.ign.fr)
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
+// Copyright (c) 2012-2013, IGN France.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
- *   You should have received a copy of the GNU Library General Public
- *   License along with this library; if not, see
- <http://www.gnu.org/licenses/>.
- */
 #include <fstream>
 #include <iostream>
 
 #include <boost/algorithm/string.hpp>
 #include <boost/program_options.hpp>
 
-#include <SFCGAL/Exception.h>
+#include "SFCGAL/Exception.h"
 
-#include <SFCGAL/GeometryCollection.h>
-#include <SFCGAL/LineString.h>
-#include <SFCGAL/MultiLineString.h>
-#include <SFCGAL/MultiPoint.h>
-#include <SFCGAL/MultiPolygon.h>
-#include <SFCGAL/MultiSolid.h>
-#include <SFCGAL/Point.h>
-#include <SFCGAL/Polygon.h>
-#include <SFCGAL/PolyhedralSurface.h>
-#include <SFCGAL/Solid.h>
-#include <SFCGAL/Triangle.h>
-#include <SFCGAL/TriangulatedSurface.h>
+#include "SFCGAL/GeometryCollection.h"
+#include "SFCGAL/LineString.h"
+#include "SFCGAL/MultiLineString.h"
+#include "SFCGAL/MultiPoint.h"
+#include "SFCGAL/MultiPolygon.h"
+#include "SFCGAL/MultiSolid.h"
+#include "SFCGAL/Point.h"
+#include "SFCGAL/Polygon.h"
+#include "SFCGAL/PolyhedralSurface.h"
+#include "SFCGAL/Solid.h"
+#include "SFCGAL/Triangle.h"
+#include "SFCGAL/TriangulatedSurface.h"
 
-#include <SFCGAL/algorithm/area.h>
-#include <SFCGAL/algorithm/force2D.h>
-#include <SFCGAL/algorithm/orientation.h>
-#include <SFCGAL/io/vtk.h>
-#include <SFCGAL/io/wkt.h>
-#include <SFCGAL/triangulate/triangulatePolygon.h>
+#include "SFCGAL/algorithm/area.h"
+#include "SFCGAL/algorithm/force2D.h"
+#include "SFCGAL/algorithm/orientation.h"
+#include "SFCGAL/io/vtk.h"
+#include "SFCGAL/io/wkt.h"
+#include "SFCGAL/triangulate/triangulatePolygon.h"
 
 #include <boost/chrono.hpp>
 
@@ -76,7 +61,7 @@ main(int argc, char *argv[]) -> int
   po::notify(vm);
 
   if (vm.count("help") != 0U) {
-    std::cout << desc << std::endl;
+    std::cout << desc << '\n';
     return 0;
   }
 
@@ -89,8 +74,8 @@ main(int argc, char *argv[]) -> int
   if (vm.count("filename") != 0U) {
     filename = vm["filename"].as<std::string>();
   } else {
-    std::cerr << "missing input file" << std::endl;
-    std::cout << desc << std::endl;
+    std::cerr << "missing input file" << '\n';
+    std::cout << desc << '\n';
     return 1;
   }
 
@@ -106,7 +91,7 @@ main(int argc, char *argv[]) -> int
   std::ifstream ifs(filename.c_str());
 
   if (!ifs.good()) {
-    std::cerr << "fail to open : " << filename << std::endl;
+    std::cerr << "fail to open : " << filename << '\n';
     return 1;
   }
 
@@ -115,7 +100,7 @@ main(int argc, char *argv[]) -> int
   std::ofstream tri_ofs(tri_filename.c_str());
 
   if (!tri_ofs.good()) {
-    std::cerr << "fail to write : " << tri_filename << std::endl;
+    std::cerr << "fail to write : " << tri_filename << '\n';
     return 1;
   }
 
@@ -124,7 +109,7 @@ main(int argc, char *argv[]) -> int
   std::ofstream ofs_error(error_filename.c_str());
 
   if (!ofs_error.good()) {
-    std::cerr << "fail to write : " << error_filename << std::endl;
+    std::cerr << "fail to write : " << error_filename << '\n';
     return 1;
   }
 
@@ -156,7 +141,7 @@ main(int argc, char *argv[]) -> int
     }
 
     if (verbose) {
-      std::cout << "#" << line << std::endl;
+      std::cout << "#" << line << '\n';
       std::cout.flush();
     }
 
@@ -164,8 +149,7 @@ main(int argc, char *argv[]) -> int
       std::cout.width(12);
       boost::chrono::duration<double> const elapsed =
           boost::chrono::system_clock::now() - start;
-      std::cout << std::left << lineNumber << "(" << elapsed << " s)"
-                << std::endl;
+      std::cout << std::left << lineNumber << "(" << elapsed << " s)" << '\n';
     }
 
     std::vector<std::string> tokens;
@@ -210,7 +194,7 @@ main(int argc, char *argv[]) -> int
                   << "area(polygon) != area(tin) ( " << areaPolygons
                   << " !=" << areaTriangles << ")"
                   << "|" << g->asText() << "|" << triangulatedSurface.asText()
-                  << std::endl;
+                  << '\n';
       }
 
       numSuccess++;
@@ -236,7 +220,7 @@ main(int argc, char *argv[]) -> int
 
     // output triangulated surface
     tri_ofs << id << "|" << failed << "|" << triangulatedSurface.asText(5)
-            << std::endl;
+            << '\n';
   } // end for each line
 
   ofs_error.close();
@@ -253,9 +237,8 @@ main(int argc, char *argv[]) -> int
     std::cout << "    " << i << " is inapropriate for triangulation\n";
   }
 
-  std::cout << filename << " complete (" << elapsed << " s)---" << std::endl;
-  std::cout << numFailed << " failed /" << (numFailed + numSuccess)
-            << std::endl;
+  std::cout << filename << " complete (" << elapsed << " s)---" << '\n';
+  std::cout << numFailed << " failed /" << (numFailed + numSuccess) << '\n';
 
   if (numFailed == 0) {
     // delete empty error file
