@@ -1,23 +1,8 @@
-/**
- *   SFCGAL
- *
- *   Copyright (C) 2012-2013 Oslandia <infos@oslandia.com>
- *   Copyright (C) 2012-2013 IGN (http://www.ign.fr)
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
+// Copyright (c) 2012-2013, IGN France.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
- *   You should have received a copy of the GNU Library General Public
- *   License along with this library; if not, see
- <http://www.gnu.org/licenses/>.
- */
 #include "../../../test_config.h"
 
 #include <boost/format.hpp>
@@ -106,7 +91,7 @@ BOOST_AUTO_TEST_CASE(testTriangulatePolygon)
         triangulate::triangulatePolygon3D(*g, triangulatedSurface));
 
     BOOST_TEST_MESSAGE(boost::format("#%1% triangle(s)") %
-                       triangulatedSurface.numGeometries());
+                       triangulatedSurface.numPatches());
 
     /*
      * make some checks
