@@ -1,23 +1,8 @@
-/**
- *   SFCGAL
- *
- *   Copyright (C) 2012-2013 Oslandia <infos@oslandia.com>
- *   Copyright (C) 2012-2013 IGN (http://www.ign.fr)
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
+// Copyright (c) 2012-2013, IGN France.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
- *   You should have received a copy of the GNU Library General Public
- *   License along with this library; if not, see
- <http://www.gnu.org/licenses/>.
- */
 #include <boost/test/unit_test.hpp>
 
 #include "SFCGAL/Coordinate.h"
@@ -199,6 +184,53 @@ BOOST_AUTO_TEST_CASE(testAlmostEqual)
                    .almostEqual(Coordinate(0.0, 0.0, 0.000003), 0.000001));
 }
 
+BOOST_AUTO_TEST_CASE(testDropZ)
+{
+  Coordinate coord3D(1.0, 2.0, 3.0);
+  BOOST_CHECK(!coord3D.isEmpty());
+  BOOST_CHECK(coord3D.is3D());
+  BOOST_CHECK(coord3D.dropZ());
+  BOOST_CHECK(!coord3D.is3D());
+  BOOST_CHECK_EQUAL(coord3D.x(), 1.0);
+  BOOST_CHECK_EQUAL(coord3D.y(), 2.0);
+
+  Coordinate coord2D(1.0, 4.0);
+  BOOST_CHECK(!coord2D.isEmpty());
+  BOOST_CHECK(!coord2D.is3D());
+  BOOST_CHECK(!coord2D.dropZ());
+  BOOST_CHECK_EQUAL(coord2D.x(), 1.0);
+  BOOST_CHECK_EQUAL(coord2D.y(), 4.0);
+
+  Coordinate coordEmpty;
+  BOOST_CHECK(coordEmpty.isEmpty());
+  BOOST_CHECK(!coordEmpty.dropZ());
+}
+
+BOOST_AUTO_TEST_CASE(testSwapXY)
+{
+  Coordinate coord3D(1.0, 2.0, 3.0);
+  BOOST_CHECK(!coord3D.isEmpty());
+  BOOST_CHECK(coord3D.is3D());
+  coord3D.swapXY();
+  BOOST_CHECK(coord3D.is3D());
+  BOOST_CHECK_EQUAL(coord3D.x(), 2.0);
+  BOOST_CHECK_EQUAL(coord3D.y(), 1.0);
+  BOOST_CHECK_EQUAL(coord3D.z(), 3.0);
+
+  Coordinate coord2D(1.0, 4.0);
+  BOOST_CHECK(!coord2D.isEmpty());
+  BOOST_CHECK(!coord2D.is3D());
+  coord2D.swapXY();
+  BOOST_CHECK(!coord2D.is3D());
+  BOOST_CHECK_EQUAL(coord2D.x(), 4.0);
+  BOOST_CHECK_EQUAL(coord2D.y(), 1.0);
+
+  Coordinate coordEmpty;
+  BOOST_CHECK(coordEmpty.isEmpty());
+  coordEmpty.swapXY();
+  BOOST_CHECK(coordEmpty.isEmpty());
+}
+
 /// bool operator == ( const Coordinate & other ) const ;
 /// bool operator != ( const Coordinate & other ) const ;
 /// inline Kernel::Vector_2 toVector_2() const
