@@ -1,29 +1,16 @@
-/**
- *   SFCGAL
- *
- *   Copyright (C) 2012-2013 Oslandia <infos@oslandia.com>
- *   Copyright (C) 2012-2013 IGN (http://www.ign.fr)
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
+// Copyright (c) 2012-2013, IGN France.
+// Copyright (c) 2024-2025, SFCGAL team.
+// Copyright (c) 2012-2024, Oslandia.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
- *   You should have received a copy of the GNU Library General Public
- *   License along with this library; if not, see
- <http://www.gnu.org/licenses/>.
- */
+#include "SFCGAL/Geometry.h"
 #include "SFCGAL/Kernel.h"
 
 #include "SFCGAL/Envelope.h"
 #include "SFCGAL/Exception.h"
 #include "SFCGAL/GeometryCollection.h"
 #include "SFCGAL/Point.h"
+#include "SFCGAL/io/wkt.h"
 
 #include <boost/test/unit_test.hpp>
 using namespace boost::unit_test;
@@ -39,6 +26,7 @@ BOOST_AUTO_TEST_CASE(defaultConstructor)
   BOOST_CHECK(g.isEmpty());
   BOOST_CHECK(!g.is3D());
   BOOST_CHECK(!g.isMeasured());
+  BOOST_CHECK_EQUAL(g.numGeometries(), 0U);
 
   // no more access to double
   BOOST_CHECK_THROW(g.x(), Exception);
@@ -71,6 +59,24 @@ BOOST_AUTO_TEST_CASE(xyzConstructor)
   BOOST_CHECK_EQUAL(g.y(), 3.0);
   BOOST_CHECK_EQUAL(g.z(), 4.0);
 }
+
+BOOST_AUTO_TEST_CASE(dimensionConstructor)
+{
+  const double x = 1.0;
+  const double y = 2.0;
+  const double z = 3.0;
+  const double m = 4.0;
+
+  BOOST_CHECK(Point(x, y, z, m, CoordinateType::COORDINATE_XY) == Point(x, y));
+  BOOST_CHECK(Point(x, y, z, m, CoordinateType::COORDINATE_XYZ) ==
+              Point(x, y, z));
+  BOOST_CHECK(Point(x, y, z, m, CoordinateType::COORDINATE_XYZM) ==
+              Point(x, y, z, m));
+  Point xym{x, y};
+  xym.setM(m);
+  BOOST_CHECK(Point(x, y, z, m, CoordinateType::COORDINATE_XYM) == xym);
+}
+
 // Point( const Kernel::Point_2 & other ) ;
 // Point( const Kernel::Point_3 & other ) ;
 // Point( const Point & other ) ;
@@ -248,6 +254,92 @@ BOOST_AUTO_TEST_CASE(testIsMeasured)
   BOOST_CHECK(Point(2.0, 3.0, 4.0, 5.0).isMeasured());
 }
 
+BOOST_AUTO_TEST_CASE(testDropZM)
+{
+  Point ptEmpty;
+  BOOST_CHECK(ptEmpty.isEmpty());
+  BOOST_CHECK(!ptEmpty.is3D());
+  BOOST_CHECK(!ptEmpty.isMeasured());
+  BOOST_CHECK(!ptEmpty.dropZ());
+  BOOST_CHECK(!ptEmpty.dropM());
+
+  Point pt2D(2.0, 3.0);
+  BOOST_CHECK(!pt2D.is3D());
+  BOOST_CHECK(!pt2D.isMeasured());
+  BOOST_CHECK(!pt2D.dropZ());
+  BOOST_CHECK(!ptEmpty.dropM());
+
+  Point pt3D(2.0, 3.0, 4.0);
+  BOOST_CHECK(pt3D.is3D());
+  BOOST_CHECK(!pt3D.isMeasured());
+  BOOST_CHECK(pt3D.dropZ());
+  BOOST_CHECK(!pt3D.dropM());
+  BOOST_CHECK_EQUAL(pt3D.x(), 2.0);
+  BOOST_CHECK_EQUAL(pt3D.y(), 3.0);
+  BOOST_CHECK_EQUAL(pt3D.z(), 0.0);
+  BOOST_CHECK(!pt3D.is3D());
+  BOOST_CHECK(!pt3D.isMeasured());
+  BOOST_CHECK(!pt3D.dropZ());
+
+  std::unique_ptr<Geometry> ptM(io::readWkt("POINT M (2 3 4)"));
+  BOOST_REQUIRE(ptM->is<Point>());
+  BOOST_CHECK(!ptM->is3D());
+  BOOST_CHECK(ptM->isMeasured());
+  BOOST_CHECK(!ptM->dropZ());
+  BOOST_CHECK(ptM->dropM());
+  BOOST_CHECK(!ptM->isMeasured());
+  BOOST_CHECK_EQUAL(ptM->as<Point>().x(), 2.0);
+  BOOST_CHECK_EQUAL(ptM->as<Point>().y(), 3.0);
+  BOOST_CHECK_EQUAL(ptM->as<Point>().z(), 0.0);
+  BOOST_CHECK(!ptM->dropM());
+
+  Point ptZM(2.0, 3.0, 4.0, 5.0);
+  BOOST_CHECK(ptZM.is3D());
+  BOOST_CHECK(ptZM.isMeasured());
+  BOOST_CHECK(ptZM.dropM());
+  BOOST_CHECK_EQUAL(ptZM.x(), 2.0);
+  BOOST_CHECK_EQUAL(ptZM.y(), 3.0);
+  BOOST_CHECK_EQUAL(ptZM.z(), 4.0);
+  BOOST_CHECK(ptZM.is3D());
+  BOOST_CHECK(!ptZM.isMeasured());
+  BOOST_CHECK(!ptZM.dropM());
+  BOOST_CHECK(ptZM.dropZ());
+  BOOST_CHECK_EQUAL(ptZM.x(), 2.0);
+  BOOST_CHECK_EQUAL(ptZM.y(), 3.0);
+  BOOST_CHECK_EQUAL(ptZM.z(), 0.0);
+  BOOST_CHECK(!ptZM.dropZ());
+  BOOST_CHECK(!ptZM.is3D());
+  BOOST_CHECK(!ptZM.isMeasured());
+}
+
+BOOST_AUTO_TEST_CASE(testSwapXY)
+{
+  Point ptEmpty;
+  BOOST_CHECK(ptEmpty.isEmpty());
+  ptEmpty.swapXY();
+  BOOST_CHECK(ptEmpty.isEmpty());
+
+  Point pt2D(2.0, 3.0);
+  pt2D.swapXY();
+  BOOST_CHECK_EQUAL(pt2D.x(), 3.0);
+  BOOST_CHECK_EQUAL(pt2D.y(), 2.0);
+
+  Point pt3D(5.0, 3.0, 4.0);
+  pt3D.swapXY();
+  BOOST_CHECK_EQUAL(pt3D.x(), 3.0);
+  BOOST_CHECK_EQUAL(pt3D.y(), 5.0);
+
+  std::unique_ptr<Geometry> ptM(io::readWkt("POINT M (9 2 4)"));
+  ptM->swapXY();
+  BOOST_CHECK_EQUAL(ptM->as<Point>().x(), 2.0);
+  BOOST_CHECK_EQUAL(ptM->as<Point>().y(), 9.0);
+
+  Point ptZM(-2.0, -3.0, 4.0, 5.0);
+  ptZM.swapXY();
+  BOOST_CHECK_EQUAL(ptZM.x(), -3.0);
+  BOOST_CHECK_EQUAL(ptZM.y(), -2.0);
+}
+
 // TODO
 // virtual bool         Geometry::isSimple() const = 0 ;
 
@@ -265,4 +357,29 @@ BOOST_AUTO_TEST_CASE(asPoint)
   BOOST_CHECK(g->as<Point>().isEmpty());
 }
 
+// virtual size_t              numGeometries() const ;
+BOOST_AUTO_TEST_CASE(testAccessors)
+{
+  Point const g;
+  BOOST_CHECK_EQUAL(g.numGeometries(), 0U);
+
+  Point const g2D(2.0, 3.0);
+  BOOST_CHECK_EQUAL(g2D.numGeometries(), 1U);
+
+  Point const g3D(2.0, 3.0, 4.0);
+  BOOST_CHECK_EQUAL(g3D.numGeometries(), 1U);
+}
+
+BOOST_AUTO_TEST_CASE(getCoordinateType)
+{
+  BOOST_CHECK_EQUAL(io::readWkt("POINT (0 0)")->getCoordinateType(),
+                    CoordinateType::COORDINATE_XY);
+  BOOST_CHECK_EQUAL(io::readWkt("POINT Z (0 0 1)")->getCoordinateType(),
+                    CoordinateType::COORDINATE_XYZ);
+  BOOST_CHECK_EQUAL(io::readWkt("POINT M (0 0 2)")->getCoordinateType(),
+                    CoordinateType::COORDINATE_XYM);
+  BOOST_CHECK_EQUAL(io::readWkt("POINT ZM (0 0 1 2)")->getCoordinateType(),
+                    CoordinateType::COORDINATE_XYZM);
+}
+
 BOOST_AUTO_TEST_SUITE_END()
