@@ -1,28 +1,14 @@
-/**
- *   SFCGAL
- *
- *   Copyright (C) 2012-2013 Oslandia <infos@oslandia.com>
- *   Copyright (C) 2012-2013 IGN (http://www.ign.fr)
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
+// Copyright (c) 2012-2013, IGN France.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
- *   You should have received a copy of the GNU Library General Public
- *   License along with this library; if not, see
- <http://www.gnu.org/licenses/>.
- */
 #include "SFCGAL/Kernel.h"
 
 #include "SFCGAL/Envelope.h"
 #include "SFCGAL/GeometryCollection.h"
 #include "SFCGAL/Triangle.h"
+#include <SFCGAL/io/wkt.h>
 
 #include <boost/test/unit_test.hpp>
 using namespace boost::unit_test;
@@ -36,6 +22,7 @@ BOOST_AUTO_TEST_CASE(testDefaultConstructor)
 {
   Triangle const g;
   BOOST_CHECK(g.isEmpty());
+  BOOST_CHECK_EQUAL(g.numGeometries(), 0U);
 }
 // Triangle( const Kernel::Triangle_2 & triangle ) ;
 BOOST_AUTO_TEST_CASE(testConstructorTriangle_2)
@@ -47,6 +34,7 @@ BOOST_AUTO_TEST_CASE(testConstructorTriangle_2)
   Triangle g(Kernel::Triangle_2(a, b, c));
   BOOST_CHECK(!g.isEmpty());
   BOOST_CHECK(!g.is3D());
+  BOOST_CHECK_EQUAL(g.numGeometries(), 1U);
 
   BOOST_CHECK_EQUAL(g.vertex(0).toPoint_2(), a);
   BOOST_CHECK_EQUAL(g.vertex(1).toPoint_2(), b);
@@ -216,6 +204,89 @@ BOOST_AUTO_TEST_CASE(testIsEmpty)
 // virtual bool         Geometry::isMeasured() const = 0 ;
 // virtual bool         Geometry::isSimple() const = 0 ;
 
+BOOST_AUTO_TEST_CASE(testDropZM)
+{
+  Triangle triangleEmpty;
+  BOOST_CHECK(!triangleEmpty.dropZ());
+  BOOST_CHECK(!triangleEmpty.dropM());
+
+  Triangle triangle2D(Point(2.0, 3.0), Point(4.0, 5.0), Point(7.0, -1.0));
+  BOOST_CHECK(!triangle2D.dropZ());
+  BOOST_CHECK(!triangle2D.dropM());
+
+  Triangle triangle3D(Point(2.0, 3.0, 1.0), Point(4.0, 5.0, 1.0),
+                      Point(7.0, -1.0, 1.0));
+  BOOST_CHECK(!triangle3D.dropM());
+  BOOST_CHECK(triangle3D.dropZ());
+  BOOST_CHECK_EQUAL(triangle3D.asText(1),
+                    "TRIANGLE ((2.0 3.0,4.0 5.0,7.0 -1.0,2.0 3.0))");
+  BOOST_CHECK(!triangle3D.dropZ());
+
+  std::unique_ptr<Geometry> pt1M(io::readWkt("POINT M (5 3 4)"));
+  std::unique_ptr<Geometry> pt2M(io::readWkt("POINT M (2 5 4)"));
+  std::unique_ptr<Geometry> pt3M(io::readWkt("POINT M (9 -1 4)"));
+  Triangle triangleM(pt1M->as<Point>(), pt2M->as<Point>(), pt3M->as<Point>());
+  BOOST_REQUIRE(triangleM.is<Triangle>());
+  BOOST_CHECK(triangleM.isMeasured());
+  BOOST_CHECK(!triangleM.is3D());
+  BOOST_CHECK(!triangleM.dropZ());
+  BOOST_CHECK(triangleM.dropM());
+  BOOST_CHECK_EQUAL(triangleM.asText(0), "TRIANGLE ((5 3,2 5,9 -1,5 3))");
+  BOOST_CHECK(!triangleM.dropM());
+  BOOST_CHECK(!triangleM.dropZ());
+
+  Triangle triangleZM(Point(2.0, 3.0, 1.0, 2.0), Point(4.0, 5.0, 1.0, 5.0),
+                      Point(7.0, -1.0, 1.0, 7.0));
+  BOOST_CHECK(triangleZM.isMeasured());
+  BOOST_CHECK(triangleZM.is3D());
+
+  BOOST_CHECK(triangleZM.dropM());
+  BOOST_CHECK(triangleZM.is3D());
+  BOOST_CHECK(!triangleZM.isMeasured());
+  BOOST_CHECK_EQUAL(triangleZM.asText(0),
+                    "TRIANGLE Z ((2 3 1,4 5 1,7 -1 1,2 3 1))");
+  BOOST_CHECK(!triangleZM.dropM());
+
+  BOOST_CHECK(triangleZM.dropZ());
+  BOOST_CHECK_EQUAL(triangleZM.asText(0), "TRIANGLE ((2 3,4 5,7 -1,2 3))");
+  BOOST_CHECK(!triangleZM.dropZ());
+  BOOST_CHECK(!triangleZM.dropM());
+  BOOST_CHECK(!triangleZM.isMeasured());
+  BOOST_CHECK(!triangleZM.is3D());
+}
+
+BOOST_AUTO_TEST_CASE(testSwapXY)
+{
+  Triangle triangleEmpty;
+  BOOST_CHECK(triangleEmpty.isEmpty());
+  triangleEmpty.swapXY();
+  BOOST_CHECK(triangleEmpty.isEmpty());
+
+  Triangle triangle2D(Point(2.0, 3.0), Point(4.0, 5.0), Point(7.0, -1.0));
+  triangle2D.swapXY();
+  BOOST_CHECK_EQUAL(triangle2D.asText(0), "TRIANGLE ((3 2,5 4,-1 7,3 2))");
+
+  Triangle triangle3D(Point(2.0, 3.0, 1.0), Point(4.0, 5.0, 1.0),
+                      Point(7.0, -1.0, 1.0));
+  triangle3D.swapXY();
+  BOOST_CHECK_EQUAL(triangle3D.asText(0),
+                    "TRIANGLE Z ((3 2 1,5 4 1,-1 7 1,3 2 1))");
+
+  std::unique_ptr<Geometry> pt1M(io::readWkt("POINT M (2 3 4)"));
+  std::unique_ptr<Geometry> pt2M(io::readWkt("POINT M (4 5 4)"));
+  std::unique_ptr<Geometry> pt3M(io::readWkt("POINT M (7 -1 4)"));
+  Triangle triangleM(pt1M->as<Point>(), pt2M->as<Point>(), pt3M->as<Point>());
+  triangleM.swapXY();
+  BOOST_CHECK_EQUAL(triangleM.asText(0),
+                    "TRIANGLE M ((3 2 4,5 4 4,-1 7 4,3 2 4))");
+
+  Triangle triangleZM(Point(2.0, 3.0, 1.0, 2.0), Point(4.0, 5.0, 1.0, 5.0),
+                      Point(7.0, -1.0, 1.0, 7.0));
+  triangleZM.swapXY();
+  BOOST_CHECK_EQUAL(triangleZM.asText(0),
+                    "TRIANGLE ZM ((3 2 1 2,5 4 1 5,-1 7 1 7,3 2 1 2))");
+}
+
 // template < typename Derived > inline bool Geometry::is() const
 BOOST_AUTO_TEST_CASE(isTriangle)
 {
