@@ -1,23 +1,8 @@
-/**
- *   SFCGAL
- *
- *   Copyright (C) 2012-2013 Oslandia <infos@oslandia.com>
- *   Copyright (C) 2012-2013 IGN (http://www.ign.fr)
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
+// Copyright (c) 2012-2013, IGN France.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
- *   You should have received a copy of the GNU Library General Public
- *   License along with this library; if not, see
- <http://www.gnu.org/licenses/>.
- */
 #include <boost/test/unit_test.hpp>
 
 #include "SFCGAL/GeometryCollection.h"
@@ -51,7 +36,8 @@ BOOST_AUTO_TEST_CASE(testOppositeTriangle)
                                Point(0.0, 1.0, 0.0)));
   TriangulatedSurface const triangulatedSurface =
       builder.buildTriangulatedSurface();
-  BOOST_CHECK_EQUAL(triangulatedSurface.numGeometries(), 2U);
+  BOOST_CHECK_EQUAL(triangulatedSurface.numGeometries(), 1U);
+  BOOST_CHECK_EQUAL(triangulatedSurface.numPatches(), 2U);
   BOOST_CHECK(algorithm::hasConsistentOrientation3D(triangulatedSurface));
 }
 
@@ -68,7 +54,8 @@ BOOST_AUTO_TEST_CASE(testFourTriangle)
                                Point(0.0, -1.0, 0.0)));
   TriangulatedSurface const triangulatedSurface =
       builder.buildTriangulatedSurface();
-  BOOST_CHECK_EQUAL(triangulatedSurface.numGeometries(), 4U);
+  BOOST_CHECK_EQUAL(triangulatedSurface.numGeometries(), 1U);
+  BOOST_CHECK_EQUAL(triangulatedSurface.numPatches(), 4U);
   BOOST_CHECK(algorithm::hasConsistentOrientation3D(triangulatedSurface));
 }
 
