@@ -1,4 +1,5 @@
-// Copyright (c) 2012-2023, Oslandia.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <boost/test/unit_test.hpp>
@@ -52,6 +53,7 @@ BOOST_AUTO_TEST_CASE(testPartition2_YMonotonePartition2)
   exteriorRing.addPoint(Point(2.0, 2.0));
   exteriorRing.addPoint(Point(1.0, 1.0));
   exteriorRing.addPoint(Point(0.0, 2.0));
+  exteriorRing.addPoint(Point(0.0, 0.0));
 
   Polygon const g(exteriorRing);
 
@@ -59,8 +61,9 @@ BOOST_AUTO_TEST_CASE(testPartition2_YMonotonePartition2)
       algorithm::partition_2(g, SFCGAL::algorithm::y_monotone));
   BOOST_CHECK(!result->isEmpty());
 
-  std::string const expectedWKT("GEOMETRYCOLLECTION (POLYGON ((0.0 0.0,2.0 "
-                                "0.0,2.0 2.0,1.0 1.0,0.0 0.0)))");
+  std::string const expectedWKT(
+      "GEOMETRYCOLLECTION (POLYGON ((2.0 0.0,2.0 2.0,1.0 1.0,2.0 0.0)),POLYGON "
+      "((0.0 0.0,2.0 0.0,1.0 1.0,0.0 2.0,0.0 0.0)))");
   BOOST_CHECK_EQUAL(result->asText(1), expectedWKT);
 }
 
