@@ -1,23 +1,8 @@
-/**
- *   SFCGAL
- *
- *   Copyright (C) 2012-2013 Oslandia <infos@oslandia.com>
- *   Copyright (C) 2012-2013 IGN (http://www.ign.fr)
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
+// Copyright (c) 2012-2013, IGN France.
+// Copyright (c) 2012-2024, Oslandia.
+// Copyright (c) 2024-2025, SFCGAL team.
+// SPDX-License-Identifier: LGPL-2.0-or-later
 
- *   You should have received a copy of the GNU Library General Public
- *   License along with this library; if not, see
- <http://www.gnu.org/licenses/>.
- */
 #include <boost/test/unit_test.hpp>
 
 #include "SFCGAL/GeometryCollection.h"
@@ -264,7 +249,7 @@ BOOST_AUTO_TEST_CASE(testDegenerateMultiLineString)
       "1297000 200400, 1296000 200400, 1294585.78643762995488942 "
       "200985.78643762698629871),(1297000 202400, 1297000 212400, 1296000 "
       "212400, 1296000 202400, 1297000 202400))"));
-  const double                    tolerance = 1e-8;
+  const double                    tolerance = EPSILON;
   std::unique_ptr<Geometry>       out(
       algorithm::straightSkeleton(*g, tolerance != 0.0));
   for (size_t i = 0; i < out->numGeometries(); i++) {
@@ -272,32 +257,49 @@ BOOST_AUTO_TEST_CASE(testDegenerateMultiLineString)
   }
 }
 
+BOOST_AUTO_TEST_CASE(testEmptyExtrudeStraightSkeleton)
+{
+  std::unique_ptr<Geometry> const    geom(io::readWkt("POLYGON EMPTY"));
+  std::unique_ptr<PolyhedralSurface> out(
+      algorithm::extrudeStraightSkeleton(*geom, 2.0));
+  std::string const expectedWKT("POLYHEDRALSURFACE EMPTY");
+  BOOST_CHECK_EQUAL(out->asText(2), expectedWKT);
+}
+
+BOOST_AUTO_TEST_CASE(testEmptyExtrudeStraightSkeletonRoofTop)
+{
+  std::unique_ptr<Geometry> const    geom(io::readWkt("POLYGON EMPTY"));
+  std::unique_ptr<PolyhedralSurface> out(
+      algorithm::extrudeStraightSkeleton(*geom, 2.0, 10.0));
+  std::string const expectedWKT("POLYHEDRALSURFACE EMPTY");
+  BOOST_CHECK_EQUAL(out->asText(2), expectedWKT);
+}
+
 BOOST_AUTO_TEST_CASE(testExtrudeStraightSkeleton)
 {
 
-  std::unique_ptr<Geometry> const g(
+  std::unique_ptr<Geometry> const geom(
       io::readWkt("POLYGON (( 0 0, 5 0, 5 5, 4 5, 4 4, 0 4, 0 0 ))"));
   std::unique_ptr<PolyhedralSurface> out(
-      algorithm::extrudeStraightSkeleton(*g, 2.0));
+      algorithm::extrudeStraightSkeleton(*geom, 2.0));
   std::string const expectedWKT(
       "POLYHEDRALSURFACE Z (((4.00 5.00 0.00,5.00 5.00 0.00,4.00 4.00 "
-      "0.00,4.00 "
-      "5.00 0.00)),((0.00 4.00 0.00,4.00 4.00 0.00,0.00 0.00 0.00,0.00 4.00 "
-      "0.00)),((4.00 4.00 0.00,5.00 0.00 0.00,0.00 0.00 0.00,4.00 4.00 "
-      "0.00)),((5.00 5.00 0.00,5.00 0.00 0.00,4.00 4.00 0.00,5.00 5.00 "
-      "0.00)),((0.00 4.00 0.00,0.00 0.00 0.00,2.00 2.00 2.00,0.00 4.00 "
-      "0.00)),((0.00 0.00 0.00,5.00 0.00 0.00,3.00 2.00 2.00,0.00 0.00 "
-      "0.00)),((2.00 2.00 2.00,0.00 0.00 0.00,3.00 2.00 2.00,2.00 2.00 "
-      "2.00)),((4.50 3.50 0.50,5.00 5.00 0.00,4.50 4.50 0.50,4.50 3.50 "
-      "0.50)),((3.00 2.00 2.00,5.00 0.00 0.00,4.50 3.50 0.50,3.00 2.00 "
-      "2.00)),((4.50 3.50 0.50,5.00 0.00 0.00,5.00 5.00 0.00,4.50 3.50 "
-      "0.50)),((5.00 5.00 0.00,4.00 5.00 0.00,4.50 4.50 0.50,5.00 5.00 "
-      "0.00)),((4.50 4.50 0.50,4.00 4.00 0.00,4.50 3.50 0.50,4.50 4.50 "
-      "0.50)),((4.50 4.50 0.50,4.00 5.00 0.00,4.00 4.00 0.00,4.50 4.50 "
-      "0.50)),((4.00 4.00 0.00,0.00 4.00 0.00,2.00 2.00 2.00,4.00 4.00 "
-      "0.00)),((4.50 3.50 0.50,4.00 4.00 0.00,3.00 2.00 2.00,4.50 3.50 "
-      "0.50)),((3.00 2.00 2.00,4.00 4.00 0.00,2.00 2.00 2.00,3.00 2.00 "
-      "2.00)))");
+      "0.00,4.00 5.00 0.00)),((0.00 4.00 0.00,4.00 4.00 0.00,0.00 0.00 "
+      "0.00,0.00 4.00 0.00)),((4.00 4.00 0.00,5.00 0.00 0.00,0.00 0.00 "
+      "0.00,4.00 4.00 0.00)),((5.00 5.00 0.00,5.00 0.00 0.00,4.00 4.00 "
+      "0.00,5.00 5.00 0.00)),((0.00 4.00 0.00,0.00 0.00 0.00,2.00 2.00 "
+      "2.00,0.00 4.00 0.00)),((0.00 0.00 0.00,5.00 0.00 0.00,3.00 2.00 "
+      "2.00,0.00 0.00 0.00)),((2.00 2.00 2.00,0.00 0.00 0.00,3.00 2.00 "
+      "2.00,2.00 2.00 2.00)),((4.50 3.50 0.50,5.00 5.00 0.00,4.50 4.50 "
+      "0.50,4.50 3.50 0.50)),((3.00 2.00 2.00,5.00 0.00 0.00,4.50 3.50 "
+      "0.50,3.00 2.00 2.00)),((4.50 3.50 0.50,5.00 0.00 0.00,5.00 5.00 "
+      "0.00,4.50 3.50 0.50)),((5.00 5.00 0.00,4.00 5.00 0.00,4.50 4.50 "
+      "0.50,5.00 5.00 0.00)),((4.50 4.50 0.50,4.00 4.00 0.00,4.50 3.50 "
+      "0.50,4.50 4.50 0.50)),((4.50 4.50 0.50,4.00 5.00 0.00,4.00 4.00 "
+      "0.00,4.50 4.50 0.50)),((4.00 4.00 0.00,0.00 4.00 0.00,2.00 2.00 "
+      "2.00,4.00 4.00 0.00)),((4.50 3.50 0.50,4.00 4.00 0.00,3.00 2.00 "
+      "2.00,4.50 3.50 0.50)),((3.00 2.00 2.00,4.00 4.00 0.00,2.00 2.00 "
+      "2.00,3.00 2.00 2.00)))");
   BOOST_CHECK_EQUAL(out->asText(2), expectedWKT);
 }
 
@@ -356,16 +358,15 @@ BOOST_AUTO_TEST_CASE(testExtrudeStraightSkeletonPolygonWithHole)
 BOOST_AUTO_TEST_CASE(testExtrudeStraightSkeletonGenerateBuilding)
 {
 
-  std::unique_ptr<Geometry> const g(
+  std::unique_ptr<Geometry> const geom(
       io::readWkt("POLYGON (( 0 0, 5 0, 5 5, 4 5, 4 4, 0 4, 0 0 ), (1 1, 1 2, "
                   "2 2, 2 1, 1 1))"));
   std::unique_ptr<Geometry> out(
-      algorithm::extrudeStraightSkeleton(*g, 9.0, 2.0));
+      algorithm::extrudeStraightSkeleton(*geom, 9.0, 2.0));
   std::string const expectedWKT(
       "POLYHEDRALSURFACE Z (((0.00 0.00 0.00,0.00 4.00 0.00,4.00 4.00 "
-      "0.00,4.00 "
-      "5.00 0.00,5.00 5.00 0.00,5.00 0.00 0.00,0.00 0.00 0.00),(1.00 1.00 "
-      "0.00,2.00 1.00 0.00,2.00 2.00 0.00,1.00 2.00 0.00,1.00 1.00 "
+      "0.00,4.00 5.00 0.00,5.00 5.00 0.00,5.00 0.00 0.00,0.00 0.00 0.00),(1.00 "
+      "1.00 0.00,2.00 1.00 0.00,2.00 2.00 0.00,1.00 2.00 0.00,1.00 1.00 "
       "0.00)),((0.00 0.00 0.00,0.00 0.00 9.00,0.00 4.00 9.00,0.00 4.00 "
       "0.00,0.00 0.00 0.00)),((0.00 4.00 0.00,0.00 4.00 9.00,4.00 4.00 "
       "9.00,4.00 4.00 0.00,0.00 4.00 0.00)),((4.00 4.00 0.00,4.00 4.00 "
@@ -378,17 +379,7 @@ BOOST_AUTO_TEST_CASE(testExtrudeStraightSkeletonGenerateBuilding)
       "0.00,2.00 1.00 9.00,2.00 2.00 9.00,2.00 2.00 0.00,2.00 1.00 "
       "0.00)),((2.00 2.00 0.00,2.00 2.00 9.00,1.00 2.00 9.00,1.00 2.00 "
       "0.00,2.00 2.00 0.00)),((1.00 2.00 0.00,1.00 2.00 9.00,1.00 1.00 "
-      "9.00,1.00 1.00 0.00,1.00 2.00 0.00)),((4.00 5.00 9.00,5.00 5.00 "
-      "9.00,4.00 4.00 9.00,4.00 5.00 9.00)),((2.00 1.00 9.00,5.00 0.00 "
-      "9.00,0.00 0.00 9.00,2.00 1.00 9.00)),((5.00 5.00 9.00,5.00 0.00 "
-      "9.00,4.00 4.00 9.00,5.00 5.00 9.00)),((2.00 1.00 9.00,0.00 0.00 "
-      "9.00,1.00 1.00 9.00,2.00 1.00 9.00)),((1.00 2.00 9.00,1.00 1.00 "
-      "9.00,0.00 0.00 9.00,1.00 2.00 9.00)),((0.00 4.00 9.00,2.00 2.00 "
-      "9.00,1.00 2.00 9.00,0.00 4.00 9.00)),((0.00 4.00 9.00,1.00 2.00 "
-      "9.00,0.00 0.00 9.00,0.00 4.00 9.00)),((4.00 4.00 9.00,5.00 0.00 "
-      "9.00,2.00 2.00 9.00,4.00 4.00 9.00)),((4.00 4.00 9.00,2.00 2.00 "
-      "9.00,0.00 4.00 9.00,4.00 4.00 9.00)),((2.00 2.00 9.00,5.00 0.00 "
-      "9.00,2.00 1.00 9.00,2.00 2.00 9.00)),((0.50 2.50 9.50,0.00 0.00 "
+      "9.00,1.00 1.00 0.00,1.00 2.00 0.00)),((0.50 2.50 9.50,0.00 0.00 "
       "9.00,0.50 0.50 9.50,0.50 2.50 9.50)),((1.00 3.00 10.00,0.00 4.00 "
       "9.00,0.50 2.50 9.50,1.00 3.00 10.00)),((0.50 2.50 9.50,0.00 4.00 "
       "9.00,0.00 0.00 9.00,0.50 2.50 9.50)),((2.50 0.50 9.50,5.00 0.00 "
@@ -427,7 +418,7 @@ BOOST_AUTO_TEST_CASE(testStraightSkeletonPartitionLShapedPolygon)
       io::readWkt("POLYGON ((0 0, 0 2, 1 2, 1 1, 2 1, 2 0, 0 0))"));
   std::unique_ptr<Geometry> out(algorithm::straightSkeletonPartition(*g));
   std::string const         expectedWKT(
-      "MULTIPOLYGON (((0.00 0.00,0.50 0.50,0.50 1.50,0.00 2.00)),((2.00 "
+      "POLYHEDRALSURFACE (((0.00 0.00,0.50 0.50,0.50 1.50,0.00 2.00)),((2.00 "
               "0.00,1.50 0.50,0.50 0.50,0.00 0.00)),((2.00 1.00,1.50 0.50,2.00 "
               "0.00)),((1.00 1.00,0.50 0.50,1.50 0.50,2.00 1.00)),((1.00 2.00,0.50 "
               "1.50,0.50 0.50,1.00 1.00)),((0.00 2.00,0.50 1.50,1.00 2.00)))");
@@ -439,10 +430,11 @@ BOOST_AUTO_TEST_CASE(testStraightSkeletonPartitionSimpleRectangle)
   std::unique_ptr<Geometry> g(
       io::readWkt("POLYGON ((0 0, 0 2, 3 2, 3 0, 0 0))"));
   std::unique_ptr<Geometry> out(algorithm::straightSkeletonPartition(*g));
-  BOOST_CHECK(out->is<MultiPolygon>());
-  BOOST_CHECK_EQUAL(out->as<MultiPolygon>().numGeometries(), 4);
+  BOOST_CHECK(out->is<PolyhedralSurface>());
+  BOOST_CHECK_EQUAL(out->as<PolyhedralSurface>().numGeometries(), 1);
+  BOOST_CHECK_EQUAL(out->as<PolyhedralSurface>().numPolygons(), 4);
   std::string const expectedWKT(
-      "MULTIPOLYGON (((0.00 0.00,1.00 1.00,0.00 2.00)),((3.00 0.00,2.00 "
+      "POLYHEDRALSURFACE (((0.00 0.00,1.00 1.00,0.00 2.00)),((3.00 0.00,2.00 "
       "1.00,1.00 1.00,0.00 0.00)),((3.00 2.00,2.00 1.00,3.00 0.00)),((0.00 "
       "2.00,1.00 1.00,2.00 1.00,3.00 2.00)))");
   BOOST_CHECK_EQUAL(out->asText(2), expectedWKT);
@@ -453,10 +445,11 @@ BOOST_AUTO_TEST_CASE(testStraightSkeletonPartitionComplexPolygon)
   std::unique_ptr<Geometry> g(
       io::readWkt("POLYGON ((0 0, 0 3, 1 3, 1 2, 2 2, 2 3, 3 3, 3 0, 0 0))"));
   std::unique_ptr<Geometry> out(algorithm::straightSkeletonPartition(*g));
-  BOOST_CHECK(out->is<MultiPolygon>());
-  BOOST_CHECK_EQUAL(out->as<MultiPolygon>().numGeometries(), 8);
+  BOOST_CHECK(out->is<PolyhedralSurface>());
+  BOOST_CHECK_EQUAL(out->as<PolyhedralSurface>().numGeometries(), 1);
+  BOOST_CHECK_EQUAL(out->as<PolyhedralSurface>().numPolygons(), 8);
   std::string const expectedWKT(
-      "MULTIPOLYGON (((0.00 0.00,1.00 1.00,0.50 1.50,0.50 2.50,0.00 "
+      "POLYHEDRALSURFACE (((0.00 0.00,1.00 1.00,0.50 1.50,0.50 2.50,0.00 "
       "3.00)),((3.00 0.00,2.00 1.00,1.00 1.00,0.00 0.00)),((3.00 3.00,2.50 "
       "2.50,2.50 1.50,2.00 1.00,3.00 0.00)),((2.00 3.00,2.50 2.50,3.00 "
       "3.00)),((2.00 2.00,2.50 1.50,2.50 2.50,2.00 3.00)),((1.00 2.00,0.50 "
@@ -470,9 +463,9 @@ BOOST_AUTO_TEST_CASE(testStraightSkeletonPartitionPolygonWithHole)
   std::unique_ptr<Geometry> g(io::readWkt(
       "POLYGON ((0 0, 0 4, 4 4, 4 0, 0 0), (1 1, 3 1, 3 3, 1 3, 1 1))"));
   std::unique_ptr<Geometry> out(algorithm::straightSkeletonPartition(*g));
-  BOOST_CHECK(out->is<MultiPolygon>());
+  BOOST_CHECK(out->is<PolyhedralSurface>());
   std::string const expectedWKT(
-      "MULTIPOLYGON (((0.00 0.00,0.50 0.50,0.50 3.50,0.00 4.00)),((4.00 "
+      "POLYHEDRALSURFACE (((0.00 0.00,0.50 0.50,0.50 3.50,0.00 4.00)),((4.00 "
       "0.00,3.50 0.50,0.50 0.50,0.00 0.00)),((4.00 4.00,3.50 3.50,3.50 "
       "0.50,4.00 0.00)),((0.00 4.00,0.50 3.50,3.50 3.50,4.00 4.00)),((1.00 "
       "1.00,0.50 0.50,3.50 0.50,3.00 1.00)),((1.00 3.00,0.50 3.50,0.50 "
@@ -487,9 +480,9 @@ BOOST_AUTO_TEST_CASE(testStraightSkeletonPartitionMultiPolygon)
       io::readWkt("MULTIPOLYGON (((0 0, 0 2, 2 2, 2 0, 0 0)), ((3 3, 3 5, 5 5, "
                   "5 3, 3 3)))"));
   std::unique_ptr<Geometry> out(algorithm::straightSkeletonPartition(*g));
-  BOOST_CHECK(out->is<MultiPolygon>());
+  BOOST_CHECK(out->is<PolyhedralSurface>());
   std::string const expectedWKT(
-      "MULTIPOLYGON (((0.00 0.00,1.00 1.00,0.00 2.00)),((2.00 0.00,1.00 "
+      "POLYHEDRALSURFACE (((0.00 0.00,1.00 1.00,0.00 2.00)),((2.00 0.00,1.00 "
       "1.00,0.00 0.00)),((2.00 2.00,1.00 1.00,2.00 0.00)),((0.00 2.00,1.00 "
       "1.00,2.00 2.00)),((3.00 3.00,4.00 4.00,3.00 5.00)),((5.00 3.00,4.00 "
       "4.00,3.00 3.00)),((5.00 5.00,4.00 4.00,5.00 3.00)),((3.00 5.00,4.00 "
@@ -501,9 +494,9 @@ BOOST_AUTO_TEST_CASE(testStraightSkeletonPartitionEmptyPolygon)
 {
   std::unique_ptr<Geometry> g(io::readWkt("POLYGON EMPTY"));
   std::unique_ptr<Geometry> out(algorithm::straightSkeletonPartition(*g));
-  BOOST_CHECK(out->is<MultiPolygon>());
+  BOOST_CHECK(out->is<PolyhedralSurface>());
   BOOST_CHECK(out->isEmpty());
-  std::string const expectedWKT("MULTIPOLYGON EMPTY");
+  std::string const expectedWKT("POLYHEDRALSURFACE EMPTY");
   BOOST_CHECK_EQUAL(out->asText(2), expectedWKT);
 }
 
